"""Path."""
from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ansys.edb.core.layout.layout import Layout
    from ansys.edb.core.geometry.polygon_data import PolygonData
    from ansys.edb.core.typing import NetLike, ValueLike, LayerLike

from enum import Enum

from ansys.api.edb.v1 import path_pb2, path_pb2_grpc

from ansys.edb.core.inner import messages, parser
from ansys.edb.core.primitive.primitive import Primitive
from ansys.edb.core.session import StubAccessor, StubType
from ansys.edb.core.utility.value import Value


class PathEndCapType(Enum):
    """Provides an enum representing end cap types."""

    ROUND = path_pb2.ROUND
    FLAT = path_pb2.FLAT
    EXTENDED = path_pb2.EXTENDED
    CLIPPED = path_pb2.CLIPPED
    INVALID = path_pb2.INVALID_END_CAP


class PathCornerType(Enum):
    """Provides an enum representing corner types."""

    ROUND = path_pb2.ROUND_CORNER
    SHARP = path_pb2.SHARP_CORNER
    MITER = path_pb2.MITER_CORNER


class Path(Primitive):
    """Represents a path object."""

    __stub: path_pb2_grpc.PathServiceStub = StubAccessor(StubType.path)

    @classmethod
    def create(
        cls,
        layout: Layout,
        layer: LayerLike,
        net: NetLike | None,
        width: ValueLike,
        end_cap1: PathEndCapType,
        end_cap2: PathEndCapType,
        corner_style: PathCornerType,
        points: PolygonData,
    ) -> Path:
        """Create a path.

        Parameters
        ----------
        layout : .Layout
            Layout to create the path in.
        layer : :term:`LayerLike`
            Layer to place the path on.
        net : :term:`NetLike` or None
            Net of the path.
        width : :term:`ValueLike`
            Path width.
        end_cap1 : .PathEndCapType
            End cap style for the start of the path.
        end_cap2 : .PathEndCapType
            End cap style for the end of the path.
        corner_style : .PathCornerType
            Corner style.
        points : .PolygonData
            Centerline polygon data to set.

        Returns
        -------
        Path
            Path created.
        """
        return Path(
            cls.__stub.Create(
                path_pb2.PathCreationMessage(
                    layout=layout.msg,
                    layer=messages.layer_ref_message(layer),
                    net=messages.net_ref_message(net),
                    width=messages.value_message(width),
                    end_cap1=end_cap1.value,
                    end_cap2=end_cap2.value,
                    corner=corner_style.value,
                    points=messages.polygon_data_message(points),
                )
            )
        )

    @classmethod
    @parser.to_polygon_data
    def render(
        cls,
        width: ValueLike,
        end_cap1: PathEndCapType,
        end_cap2: PathEndCapType,
        corner_style: PathCornerType,
        path: PolygonData,
    ) -> PolygonData:
        """Render a path.

        Parameters
        ----------
        width : :term:`ValueLike`
            Path width.
        end_cap1 : .PathEndCapType
            End cap style for the start of the path.
        end_cap2 : .PathEndCapType
            End cap style for the end of the path.
        corner_style : .PathCornerType
            Corner style.
        path : .PolygonData
            Polygon data to set.

        Returns
        -------
        .PolygonData
            Path rendered.
        """
        return cls.__stub.Render(
            path_pb2.PathRenderMessage(
                width=messages.value_message(width),
                end_cap1=end_cap1.value,
                end_cap2=end_cap2.value,
                corner_style=corner_style.value,
                path=messages.polygon_data_message(path),
            )
        )

    @property
    @parser.to_polygon_data
    def polygon_data(self) -> PolygonData:
        """:class:`.PolygonData`: Polygon data of this Path.

        This property is read-only.
        """
        return self.__stub.GetPolygonData(self.msg)

    @property
    @parser.to_polygon_data
    def center_line(self) -> PolygonData:
        """:class:`.PolygonData`: Center line for the path."""
        return self.__stub.GetCenterLine(self.msg)

    @center_line.setter
    def center_line(self, center_line: PolygonData):
        path_pb2.SetCenterLineMessage(
            target=self.msg, center_line=messages.polygon_data_message(center_line)
        )

    def get_end_cap_style(self) -> tuple[PathEndCapType, PathEndCapType]:
        """Get end cap styles for the path.

        Returns
        -------
        tuple of (.PathEndCapType, .PathEndCapType)

            Returns a tuple in this format:

            **(end_cap1, end_cap2)**

            **end_cap1** : End cap style of path start end cap.

            **end_cap2** : End cap style of path end end cap.
        """
        end_cap_msg = self.__stub.GetEndCapStyle(self.msg)
        return PathEndCapType(end_cap_msg.end_cap1), PathEndCapType(end_cap_msg.end_cap2)

    def set_end_cap_style(self, end_cap1: PathEndCapType, end_cap2: PathEndCapType):
        """Set end cap styles for the path.

        Parameters
        ----------
        end_cap1 : .PathEndCapType
            End cap style for the start of the path.
        end_cap2 : .PathEndCapType
            End cap style for the end of the path.
        """
        self.__stub.SetEndCapStyle(
            path_pb2.SetEndCapStyleMessage(
                target=self.msg,
                end_cap=path_pb2.EndCapStyleMessage(
                    end_cap1=end_cap1.value, end_cap2=end_cap2.value
                ),
            )
        )

    def get_clip_info(self) -> tuple[PolygonData, bool]:
        """Get the data used to clip the path.

        Returns
        -------
        tuple of (.PolygonData, bool)

            Returns a tuple in this format:

            **(clipping_poly, keep_inside)**

            **clipping_poly** : PolygonData used to clip the path.

            **keep_inside** : Indicates whether the part of the path inside the polygon is preserved.
        """
        clip_info_msg = self.__stub.GetClipInfo(self.msg)
        return (
            parser.to_polygon_data(clip_info_msg.clipping_poly),
            clip_info_msg.keep_inside,
        )

    def set_clip_info(self, clipping_poly: PolygonData, keep_inside=True):
        """Set the data used to clip the path.

        Parameters
        ----------
        clipping_poly : .PolygonData
            Polygon data to use to clip the path.
        keep_inside : bool, default: True
            Whether the part of the path inside the polygon should be preserved.
        """
        self.__stub.SetClipInfo(
            path_pb2.SetClipInfoMessage(
                target=self.msg,
                clipping_poly=messages.polygon_data_message(clipping_poly),
                keep_inside=keep_inside,
            )
        )

    @property
    def corner_style(self) -> PathCornerType:
        """:class:`PathCornerType`: Corner style of the path."""
        return PathCornerType(self.__stub.GetCornerStyle(self.msg).corner_style)

    @corner_style.setter
    def corner_style(self, corner_type: PathCornerType):
        self.__stub.SetCornerStyle(
            path_pb2.SetCornerStyleMessage(
                target=self.msg,
                corner_style=path_pb2.CornerStyleMessage(corner_style=corner_type.value),
            )
        )

    @property
    def width(self) -> Value:
        """:class:`.Value`: Path width."""
        return Value(self.__stub.GetWidth(self.msg).width)

    @width.setter
    def width(self, width: ValueLike):
        self.__stub.SetWidth(
            path_pb2.SetWidthMessage(
                target=self.msg,
                width=path_pb2.WidthMessage(width=messages.value_message(width)),
            )
        )

    @property
    def miter_ratio(self) -> Value:
        """:class:`.Value`: Miter ratio."""
        return Value(self.__stub.GetMiterRatio(self.msg).miter_ratio)

    @miter_ratio.setter
    def miter_ratio(self, miter_ratio: ValueLike):
        self.__stub.SetMiterRatio(
            path_pb2.SetMiterRatioMessage(
                target=self.msg,
                miter_ratio=path_pb2.MiterRatioMessage(
                    miter_ratio=messages.value_message(miter_ratio)
                ),
            )
        )

    @property
    def can_be_zone_primitive(self) -> bool:
        """:obj:`bool`: Flag indicating if the path can be a zone.

        This property is read-only.
        """
        return True



"""Material property thermal modifier."""

from ansys.api.edb.v1 import material_property_thermal_modifier_pb2_grpc
import ansys.api.edb.v1.material_property_thermal_modifier_pb2 as pb

from ansys.edb.core.inner import ObjBase, messages
from ansys.edb.core.session import StubAccessor, StubType
from ansys.edb.core.utility.material_property_thermal_modifier_params import (
    AdvancedQuadraticParams,
    BasicQuadraticParams,
)
from ansys.edb.core.utility.value import Value


class MaterialPropertyThermalModifier(ObjBase):
    """Representing material property thermal modifiers."""

    __stub: material_property_thermal_modifier_pb2_grpc.MaterialPropertyThermalModifierServiceStub = StubAccessor(
        StubType.material_property_thermal_modifier
    )

    @classmethod
    def create(cls, basic_quadratic_params=None, advanced_quadratic_params=None):
        """Create a material property thermal modifier.

        Parameters
        ----------
        basic_quadratic_params : :class:`.BasicQuadraticParams`, default: None
            Basic parameters needed for the thermal modifier.
        advanced_quadratic_params : :class:`.AdvancedQuadraticParams`, default: None
            Advanced parameeteres needed for the thermal modifier.

        Returns
        -------
        MaterialPropertyThermalModifier
            Material property thermal modifier created.
        """
        if basic_quadratic_params is None:
            basic_quadratic_params = BasicQuadraticParams()
        if advanced_quadratic_params is None:
            advanced_quadratic_params = AdvancedQuadraticParams()
        return MaterialPropertyThermalModifier(
            cls.__stub.Create(
                pb.MaterialPropertyThermalModifierParamsMessage(
                    temp_ref=messages.value_message(basic_quadratic_params.temp_ref_val),
                    c1=messages.value_message(basic_quadratic_params.c1_val),
                    c2=messages.value_message(basic_quadratic_params.c2_val),
                    temp_lower_limit=messages.value_message(
                        advanced_quadratic_params.temp_lower_limit_val
                    ),
                    temp_upper_limit=messages.value_message(
                        advanced_quadratic_params.temp_upper_limit_val
                    ),
                    auto_calc_constant_thermal_modifier=(
                        advanced_quadratic_params.auto_calc_constant_thermal_modifier_vals
                    ),
                    lower_const_therm_mod=messages.value_message(
                        advanced_quadratic_params.lower_constant_thermal_modifier_val
                    ),
                    upper_const_therm_mod=messages.value_message(
                        advanced_quadratic_params.upper_constant_thermal_modifier_val
                    ),
                )
            )
        )

    @property
    def quadratic_model_params(self):
        """:class:`.BasicQuadraticParams`, :class:`.AdvancedQuadraticParams`: \
        Quadratic model parameters of the thermal modifier.

        The quadratic model is in this form: \
        PropVal(Temp) = PropValRef[1 + C1(Temp - TempRef) + C2(Temp - TempRef)^2]
        where PropValRef = The original property value without the thermal modifier applied

        This property is read-only.
        """
        msg = self.__stub.GetQuadraticModelParams(messages.edb_obj_message(self))
        return BasicQuadraticParams(
            Value(msg.temp_ref),
            Value(msg.c1),
            Value(msg.c2),
        ), AdvancedQuadraticParams(
            Value(msg.temp_lower_limit),
            Value(msg.temp_upper_limit),
            msg.auto_calc_constant_thermal_modifier,
            Value(msg.lower_const_therm_mod),
            Value(msg.upper_const_therm_mod),
        )

    @property
    def expression(self):
        """:class:`.Value`: Expression value representing the thermal modifier.

        This property is read-only.
        """
        return Value(self.__stub.GetThermalModifierExpression(messages.edb_obj_message(self)))



"""Temperature settings."""
from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ansys.edb.core.typing import ValueLike

from ansys.edb.core.utility.value import Value


class TemperatureSettings:
    """
    Provides temperature settings.

    Attributes
    ----------
    include_temp_dependence : bool
        Whether to include temperature dependence.
    enable_thermal_feedback : bool
        Whether to enable thermal feedback.
    temperature : :term:`ValueLike`
        Temperature value.
    """

    def __init__(
        self, include_temp_dependence: bool, enable_thermal_feedback: bool, temperature: ValueLike
    ):
        """Initialize temperature settings.

        Parameters
        ----------
        include_temp_dependence : bool
            Whether to include temperature dependence.
        enable_thermal_feedback : bool
            Whether to enable thermal feedback.
        temperature : :term:`ValueLike`
            Temperature value.
        """
        self.include_temp_dependence = include_temp_dependence
        self.enable_thermal_feedback = enable_thermal_feedback
        self.temperature = temperature

    def __eq__(self, other: TemperatureSettings) -> bool:
        """Compare equality with another object."""
        if isinstance(other, TemperatureSettings):
            return (
                self.include_temp_dependence == other.include_temp_dependence
                and self.enable_thermal_feedback == other.enable_thermal_feedback
                and Value(self.temperature) == Value(other.temperature)
            )
        return False



"""Dataset definition."""
from __future__ import annotations

from typing import TYPE_CHECKING, List

if TYPE_CHECKING:
    from ansys.edb.core.database import Database
    from ansys.edb.core.geometry.point_data import PointData

from ansys.api.edb.v1.dataset_def_pb2_grpc import DatasetDefServiceStub

from ansys.edb.core.edb_defs import DefinitionObjType
from ansys.edb.core.inner import ObjBase
from ansys.edb.core.inner.messages import (
    edb_obj_message,
    edb_obj_name_message,
    points_property_message,
    string_property_message,
)
from ansys.edb.core.inner.parser import to_point_data_list
from ansys.edb.core.session import StubAccessor, StubType


class DatasetDef(ObjBase):
    """A collection of data points which can be used to define piecewise functions."""

    __stub: DatasetDefServiceStub = StubAccessor(StubType.dataset_def)

    @classmethod
    def create(cls, database: Database, name: str) -> DatasetDef:
        """Create a dataset definition object.

        Parameters
        ----------
        database : .Database
            Database to create the dataset definition in.
        name : str
            Name of the dataset definition to create.

        Returns
        -------
        .DatasetDef
        """
        return DatasetDef(cls.__stub.Create(string_property_message(database, name)))

    @classmethod
    def find_by_name(cls, database: Database, name: str) -> DatasetDef:
        """Find a dataset definition by name in a given database.

        Parameters
        ----------
        database : .Database
            Database to search for the dataset definition in.
        name : str
            Name of the dataset definition.

        Returns
        -------
        .DatasetDef
            Dataset definition object found.
            If a dataset definition isn't found, the returned dataset definition is :meth:`null <.is_null>`.
        """
        return DatasetDef(cls.__stub.FindByName(edb_obj_name_message(database, name)))

    @property
    def definition_type(self) -> DefinitionObjType:
        """:class:`.DefinitionObjType`: Definition type.

        This property is read-only.
        """
        return DefinitionObjType.DATASET_DEF

    @property
    def name(self) -> str:
        """:obj:`str`: Name of the dataset definition."""
        return self.__stub.GetName(edb_obj_message(self)).value

    @name.setter
    def name(self, name: str):
        self.__stub.SetName(string_property_message(self, name))

    @to_point_data_list
    def get_data(self) -> List[PointData]:
        """Get the collection of data points the dataset definition represents.

        Returns
        -------
        list of .PointData
        """
        msg = self.__stub.GetData(edb_obj_message(self))
        return msg.points

    def set_data(self, points: List[PointData]):
        """Set the collection of data points the dataset definition represents.

        Parameters
        ----------
        points : list of .PointData
        """
        self.__stub.SetData(points_property_message(self, points))



"""Group."""

from ansys.api.edb.v1.group_pb2 import GroupTypeMessage
from ansys.api.edb.v1.group_pb2_grpc import GroupServiceStub

from ansys.edb.core.edb_defs import LayoutObjType
from ansys.edb.core.hierarchy.hierarchy_obj import HierarchyObj
from ansys.edb.core.inner import messages
from ansys.edb.core.inner.utils import query_lyt_object_collection
from ansys.edb.core.session import StubAccessor, StubType


class Group(HierarchyObj):
    """Represents a group object."""

    __stub: GroupServiceStub = StubAccessor(StubType.group)
    layout_obj_type = LayoutObjType.GROUP

    def cast(self):
        """Cast the group object to the correct concrete type.

        Returns
        -------
        Group
        """
        from ansys.edb.core.hierarchy.component_group import ComponentGroup
        from ansys.edb.core.hierarchy.structure3d import Structure3D
        from ansys.edb.core.hierarchy.via_group import ViaGroup

        if self.is_null:
            return

        group_type = self.__stub.GetGroupType(self.msg).group_type
        if group_type == GroupTypeMessage.GroupType.GROUP:
            return Group(self.msg)
        elif group_type == GroupTypeMessage.GroupType.COMPONENT:
            return ComponentGroup(self.msg)
        elif group_type == GroupTypeMessage.GroupType.STRUCTURE_3D:
            return Structure3D(self.msg)
        elif group_type == GroupTypeMessage.GroupType.VIA_GROUP:
            return ViaGroup(self.msg)

    @classmethod
    def create(cls, layout, name):
        """Create a group.

        Parameters
        ----------
        layout : :class:`.Layout`
            Layout to create the group in.
        name : str
            Name of the group.

        Returns
        -------
        Group
           Group created.
        """
        return Group(cls.__stub.Create(messages.object_name_in_layout_message(layout, name)))

    @classmethod
    def find(cls, layout, name):
        """Find a group by name.

        Parameters
        ----------
        layout : :class:`.Layout`
            Layout to search for the group.
        name : str
            Name of the group.

        Returns
        -------
        Group
            Group that is found, ``None`` otherwise.
        """
        return Group(
            cls.__stub.FindByName(messages.object_name_in_layout_message(layout, name))
        ).cast()

    def add_member(self, member):
        """Add an object to the group.

        Parameters
        ----------
        member : :term:`Connectable`
            Object to add to the group.
        """
        self.__stub.AddMember(messages.group_modify_member_message(self, member))

    def remove_member(self, member):
        """Remove an object from the group.

        Parameters
        ----------
        member : :term:`Connectable`
            Object to remove from the group.
        """
        self.__stub.RemoveMember(messages.group_modify_member_message(self, member))

    def ungroup(self, recursive):
        """Dissolve the group.

        Parameters
        ----------
        recursive : bool
            Whether all containing groups should also be resolved.
        """
        self.__stub.Ungroup(messages.bool_property_message(self, recursive))

    @property
    def members(self):
        """:obj:`list` of :term:`Connectables <Connectable>`: All group members.

        This property is read-only.
        """
        return query_lyt_object_collection(
            self,
            LayoutObjType.INVALID_LAYOUT_OBJ,
            self.__stub.GetMembers,
            self.__stub.StreamMembers,
            False,
        )



"""MCAD model."""

from ansys.edb.core.inner import ObjBase, messages, parser
from ansys.edb.core.session import McadModelServiceStub, StubAccessor, StubType


class McadModel(ObjBase):
    """Class representing an MCAD mdel."""

    __stub: McadModelServiceStub = StubAccessor(StubType.mcad_model)

    @classmethod
    def create_stride(cls, connectable=None, layout=None, filename=None):
        """Create a Stride model.

        This method makes a call directly on a :term:`Connectable` or
        :func:`Layout <ansys.edb.core.layout.layout.Layout.create_stride>`.
        """
        return cls(
            cls.__stub.CreateStride(
                messages.mcad_model_creation_message(connectable, layout, filename)
            )
        )

    @classmethod
    def create_hfss(cls, connectable=None, layout=None, filename=None, design=None):
        """Create an HFSS model.

        This method makes a call directly on a :term:`Connectable` or
        :func:`Layout <ansys.edb.core.layout.layout.Layout.create_hfss>`.
        """
        return cls(
            cls.__stub.CreateHfss(
                messages.mcad_model_hfss_creation_message(connectable, layout, filename, design)
            )
        )

    @classmethod
    def create_3d_comp(cls, connectable=None, layout=None, filename=None):
        """Create a 3D component model.

        This method makes a call directly on a :term:`Connectable` or
        :func:`Layout <ansys.edb.core.layout.Layout.create_3d_comp>`.
        """
        return cls(
            cls.__stub.Create3dComp(
                messages.mcad_model_creation_message(connectable, layout, filename)
            )
        )

    @classmethod
    def is_mcad(cls, connectable):
        """Determine if a connectable object is an MCAD model.

        This method makes a call directly on a :term:`Connectable`.
        """
        return cls.__stub.IsMcad(messages.edb_obj_message(connectable)).value

    @classmethod
    def is_mcad_stride(cls, connectable):
        """Determine if a connectable object is a Stride model.

        This method makes a call directly on a :term:`Connectable`.
        """
        return cls.__stub.IsMcadStride(messages.edb_obj_message(connectable)).value

    @classmethod
    def is_mcad_hfss(cls, connectable):
        """Determine if a connectable object is an HFSS model.

        This method makes a call directly on a :term:`Connectable`.
        """
        return cls.__stub.IsMcadHfss(messages.edb_obj_message(connectable)).value

    @classmethod
    def is_mcad_3d_comp(cls, connectable):
        """Determine if a connectable object is a 3D component model.

        This method makes a call directly on a :term:`Connectable`.
        """
        return cls.__stub.IsMcad3dComp(messages.edb_obj_message(connectable)).value

    @property
    def cell_instance(self):
        """:class:`.CellInstance`: Cell instance \
        of the MCAD model.

        This property is read-only.
        """
        from ansys.edb.core.hierarchy import cell_instance

        return cell_instance.CellInstance(self.__stub.GetCellInst(messages.edb_obj_message(self)))

    @property
    def model_name(self):
        """:obj:`str`: Name of the MCAD model.

        This property is read-only.
        """
        return self.__stub.GetModelName(messages.edb_obj_message(self)).value

    @property
    def design_name(self):
        """:obj:`str`: Design name of the MCAD model.

        This property is read-only.
        """
        return self.__stub.GetDesignName(messages.edb_obj_message(self)).value

    @property
    @parser.to_point3d_data
    def origin(self):
        """:class:`.Point3DData`: \
        Origin 3D point of the MCAD model."""
        return self.__stub.GetOrigin(messages.edb_obj_message(self))

    @origin.setter
    def origin(self, pnt):
        self.__stub.SetOrigin(messages.point_3d_property_message(self, pnt))

    @property
    def rotation(self):
        r""":obj:`tuple`\[:class:`.Point3DData`, :class:`.Point3DData`, :obj:`float`\]: Rotation from/to the axis and the angle."""  # noqa
        msg = self.__stub.GetRotation(messages.edb_obj_message(self))
        return (
            parser.to_point3d_data(msg.axis_from),
            parser.to_point3d_data(msg.axis_to),
            msg.angle.value,
        )

    @rotation.setter
    def rotation(self, value):
        self.set_rotation(*value)

    def set_rotation(self, axis_from, axis_to, angle):
        """Set rotation from/to the axis and the angle in radians.

        Parameters
        ----------
        axis_from : :class:`.Point3DData`
        axis_to : :class:`.Point3DData`
        angle : float
            Angle in radians.
        """
        self.__stub.SetRotation(
            messages.mcad_model_set_rotation_message(self, axis_from, axis_to, angle)
        )

    @property
    def scale(self):
        """:obj:`float`: Scale of the MCAD model."""
        return self.__stub.GetScale(messages.edb_obj_message(self)).value

    @scale.setter
    def scale(self, scale):
        self.__stub.SetScale(messages.double_property_message(self, scale))

    def material(self, index):
        """Get the material name of the MCAD model part at a given index.

        Parameters
        ----------
        index : int
            Index of the MCAD model part.

        Returns
        -------
        str
            Material name.
        """
        return self.__stub.GetMaterial(messages.int_property_message(self, index)).value

    def set_material(self, index, material):
        """Set material name of a MCAD model part at a given index.

        Parameters
        ----------
        index : int
            Index of the MCAD model part.
        material : str
           New material name.
        """
        self.__stub.SetMaterial(messages.mcad_model_string_message(self, index, material))

    def visible(self, index):
        """Get visibility of a MCAD model part at a given index.

        Parameters
        ----------
        index : int
            Index of the MCAD model part.

        Returns
        -------
        bool
        """
        return self.__stub.GetVisible(messages.int_property_message(self, index)).value

    def set_visible(self, index, visible):
        """Set visibility of an MCAD model part at a given index.

        Parameters
        ----------
        index : int
            Index of the MCAD model part.
        visible : bool
        """
        self.__stub.SetVisible(messages.mcad_model_bool_message(self, index, visible))

    def modeled(self, index):
        """Determine if an MCAD model part at a given index is included in the analysis.

        Parameters
        ----------
        index : int
            Index of the MCAD model part.

        Returns
        -------
        bool
            ``True`` if the MCAD model part is included in the analysis, ``False`` otherwise.
        """
        return self.__stub.GetModeled(messages.int_property_message(self, index)).value

    def set_modeled(self, index, modeled):
        """Set if an MCAD model part at a given index is to be modeled.

        Parameters
        ----------
        index : int
            Index of the MCAD model part.
        modeled : bool
            Whether to model the MCAD model part.
        """
        self.__stub.SetModeled(messages.mcad_model_bool_message(self, index, modeled))

    def part_count(self):
        """Get the MCAD model part count.

        Returns
        -------
        int
            MCAD model part count.
        """
        return self.__stub.GetPartCount(messages.edb_obj_message(self)).value

    def part_index(self, name):
        """Get the index of an MCAD model part with a given name.

        Parameters
        ----------
        name : str
            Name of the MCAD model part.

        Returns
        -------
        int
           Index of the MCAD model part.
        """
        return self.__stub.GetPartIndex(messages.string_property_message(self, name)).value

    def part_name(self, index):
        """Get the name of an MCAD model part at a given index.

        Parameters
        ----------
        index : int
            Index of the MCAD model part.

        Returns
        -------
        str
           Name of the MCAD model part.
        """
        return self.__stub.GetPartName(messages.int_property_message(self, index)).value



"""SIWave DCIR simulation settings."""

import ansys.api.edb.v1.si_wave_dcir_simulation_settings_pb2 as pb

from ansys.edb.core.inner import messages
from ansys.edb.core.session import SIWaveDCIRSimulationSettingsServiceStub, StubAccessor, StubType
from ansys.edb.core.simulation_setup.siwave_simulation_settings import SIWaveSimulationSettings


class SIWaveDCIRSimulationSettings(SIWaveSimulationSettings):
    """Represents SIWave DCIR simulation settings."""

    __stub: SIWaveDCIRSimulationSettingsServiceStub = StubAccessor(
        StubType.siwave_dcir_sim_settings
    )

    @property
    def icepak_temp_file(self):
        """:obj:`bool`: Path to the file containing the Icepak temperature map to import."""
        return self.__stub.GetIcepakTempFile(self.msg).value

    @icepak_temp_file.setter
    def icepak_temp_file(self, icepak_temp_file):
        self.__stub.SetIcepakTempFile(messages.string_property_message(self, icepak_temp_file))

    @property
    def source_terms_to_ground(self):
        """:obj:`dict` { :obj:`str` : :obj:`int` }: Dictionary of ``SourceName, NodeToGround`` pairs.

        ``NodeToGround`` options are ``0`` (unspecified), ``1`` (negative), and ``2`` (positive).
        """
        return {
            source: t_to_g
            for (source, t_to_g) in self.__stub.GetSourceTermsToGround(
                self.msg
            ).source_terms_to_ground.items()
        }

    @source_terms_to_ground.setter
    def source_terms_to_ground(self, source_terms_to_ground):
        self.__stub.SetSourceTermsToGround(
            pb.SourceTermsToGroundPropertyMessage(
                target=self.msg,
                value=pb.SourceTermsToGroundMessage(source_terms_to_ground=source_terms_to_ground),
            )
        )

    @property
    def export_dc_thermal_data(self):
        """:obj:`bool`: Flag indicating if DC thermal data is exported."""
        return self.__stub.GetExportDCThermalData(self.msg).value

    @export_dc_thermal_data.setter
    def export_dc_thermal_data(self, export_dc_thermal_data):
        self.__stub.SetExportDCThermalData(
            messages.bool_property_message(self, export_dc_thermal_data)
        )

    @property
    def import_thermal_data(self):
        """:obj:`bool`: Flag indicating if thermal data is imported."""
        return self.__stub.GetImportThermalData(self.msg).value

    @import_thermal_data.setter
    def import_thermal_data(self, import_thermal_data):
        self.__stub.SetImportThermalData(messages.bool_property_message(self, import_thermal_data))

    @property
    def full_dc_report_path(self):
        """:obj:`str`: Path to the DC report."""
        return self.__stub.GetFullDCReportPath(self.msg).value

    @full_dc_report_path.setter
    def full_dc_report_path(self, full_dc_report_path):
        self.__stub.SetFullDCReportPath(messages.string_property_message(self, full_dc_report_path))

    @property
    def via_report_path(self):
        """:obj:`str`: Path to the via report."""
        return self.__stub.GetViaReportPath(self.msg).value

    @via_report_path.setter
    def via_report_path(self, via_report_path):
        self.__stub.SetViaReportPath(messages.string_property_message(self, via_report_path))

    @property
    def per_pin_res_path(self):
        """:obj:`str`: Path to the per pin resolution."""
        return self.__stub.GetPerPinResPath(self.msg).value

    @per_pin_res_path.setter
    def per_pin_res_path(self, per_pin_res_path):
        self.__stub.SetPerPinResPath(messages.string_property_message(self, per_pin_res_path))

    @property
    def dc_report_config_file(self):
        """:obj:`str`: Configuration file for the DC report."""
        return self.__stub.GetDCReportConfigFile(self.msg).value

    @dc_report_config_file.setter
    def dc_report_config_file(self, dc_report_config_file):
        self.__stub.SetDCReportConfigFile(
            messages.string_property_message(self, dc_report_config_file)
        )

    @property
    def dc_report_show_active_devices(self):
        """:obj:`bool`: Flag indicating if active devices are shown in the DC report."""
        return self.__stub.GetDCReportShowActiveDevices(self.msg).value

    @dc_report_show_active_devices.setter
    def dc_report_show_active_devices(self, dc_report_show_active_devices):
        self.__stub.SetDCReportShowActiveDevices(
            messages.bool_property_message(self, dc_report_show_active_devices)
        )

    @property
    def per_pin_use_pin_format(self):
        """:obj:`bool`: Flag indicating if the per pin uses the pin format."""
        return self.__stub.GetPerPinUsePinFormat(self.msg).value

    @per_pin_use_pin_format.setter
    def per_pin_use_pin_format(self, per_pin_use_pin_format):
        self.__stub.SetPerPinUsePinFormat(
            messages.bool_property_message(self, per_pin_use_pin_format)
        )

    @property
    def use_loop_res_for_per_pin(self):
        """:obj:`bool`: Flag indicating if the per pin uses the loop resolution."""
        return self.__stub.GetUseLoopResForPerPin(self.msg).value

    @use_loop_res_for_per_pin.setter
    def use_loop_res_for_per_pin(self, use_loop_res_for_per_pin):
        self.__stub.SetUseLoopResForPerPin(
            messages.bool_property_message(self, use_loop_res_for_per_pin)
        )



"""Database."""
from __future__ import annotations

from typing import TYPE_CHECKING, List, Tuple

if TYPE_CHECKING:
    from ansys.edb.core.inner.messages import EDBObjMessage

from enum import Enum

import ansys.api.edb.v1.database_pb2 as database_pb2
import ansys.api.edb.v1.edb_defs_pb2 as edb_defs_pb2
import google.protobuf.wrappers_pb2 as proto_wrappers

from ansys.edb.core.definition.bondwire_def import (
    ApdBondwireDef,
    BondwireDefType,
    Jedec4BondwireDef,
    Jedec5BondwireDef,
)
from ansys.edb.core.definition.component_def import ComponentDef
from ansys.edb.core.definition.dataset_def import DatasetDef
from ansys.edb.core.definition.material_def import MaterialDef
from ansys.edb.core.definition.package_def import PackageDef
from ansys.edb.core.definition.padstack_def import PadstackDef
from ansys.edb.core.edb_defs import DefinitionObjType
from ansys.edb.core.inner import ObjBase, variable_server
from ansys.edb.core.inner.messages import (
    double_property_message,
    edb_obj_collection_message,
    edb_obj_name_message,
    get_product_property_ids_message,
    get_product_property_message,
    set_product_property_message,
    str_message,
)
from ansys.edb.core.inner.utils import map_list
from ansys.edb.core.layout.cell import Cell
from ansys.edb.core.session import DatabaseServiceStub, StubAccessor, StubType


class ProductIdType(Enum):
    """Enum representing IDs of Ansys products that support EDB usage."""

    HFSS_3D_LAYOUT = DESIGNER = edb_defs_pb2.DESIGNER
    SIWAVE = edb_defs_pb2.SI_WAVE
    GENERIC_TRANSLATOR = edb_defs_pb2.GENERIC_TRANSLATOR
    USER_DEFINED = edb_defs_pb2.USER_DEFINED
    INVALID_PRODUCT = edb_defs_pb2.INVALID_PRODUCT


class Database(ObjBase, variable_server.VariableServer):
    """Represents a database object."""

    __stub: DatabaseServiceStub = StubAccessor(StubType.database)

    def __init__(self, msg: EDBObjMessage):
        """Initialize a new database.

        Parameters
        ----------
        msg : .EDBObjMessage
        """
        ObjBase.__init__(self, msg)
        variable_server.VariableServer.__init__(self, self)

    @classmethod
    def create(cls, db_path: str) -> Database:
        """Create a database in a given location.

        Parameters
        ----------
        db_path : str
            Path to the top-level database directory.

        Returns
        -------
        .Database
        """
        msg = cls.__stub.Create(proto_wrappers.StringValue(value=db_path))
        return Database(msg)

    @classmethod
    def open(cls, db_path: str, read_only: bool) -> Database:
        """Open a database in a given location.

        Parameters
        ----------
        db_path : str
            Path to the top-level database directory.
        read_only : bool
            Whether to open the database in read-only mode.

        Returns
        -------
        .Database
        """
        return Database(
            cls.__stub.Open(
                database_pb2.OpenDatabaseMessage(
                    edb_path=db_path,
                    read_only=read_only,
                )
            )
        )

    @classmethod
    def delete(cls, db_path: str):
        """Delete a database in a given specified location.

        Parameters
        ----------
        db_path : str
            Path to the top-level database directory.
        """
        cls.__stub.Delete(proto_wrappers.StringValue(value=db_path))

    def save(self):
        """Save any changes to the database."""
        self.__stub.Save(self.msg)

    def close(self):
        """Close the database.

        .. note::
            Unsaved changes are lost.
        """
        self.__stub.Close(self.msg)
        self.msg = None

    @staticmethod
    def _map_cell_edb_obj_collection(cells_msg: EDBObjMessage) -> List[Cell]:
        """Get a list of cell objects from the :class:`.EDBObjCollection` message."""
        return map_list(cells_msg.items, Cell)

    @property
    def top_circuit_cells(self) -> List[Cell]:
        """:obj:`list` of :class:`.Cell`: Top circuit cells in the database."""
        return Database._map_cell_edb_obj_collection(self.__stub.GetTopCircuits(self.msg))

    @property
    def circuit_cells(self) -> List[Cell]:
        """:obj:`list` of :class:`.Cell`: All circuit cells in the database."""
        return Database._map_cell_edb_obj_collection(self.__stub.GetCircuits(self.msg))

    @property
    def footprint_cells(self) -> List[Cell]:
        """:obj:`list` of :class:`.Cell`: All footprint cells in the database."""
        return Database._map_cell_edb_obj_collection(self.__stub.GetFootprints(self.msg))

    @property
    def edb_uid(self) -> int:
        """:obj:`int`: Unique EDB ID of the database."""
        return self.__stub.GetId(self.msg).value

    @property
    def is_read_only(self) -> bool:
        """:obj:`bool`: Flag indicating if the database is open in read-only mode."""
        return self.__stub.IsReadOnly(self.msg).value

    @classmethod
    def find_by_id(cls, db_id: int) -> Database:
        """Find a database by ID.

        Parameters
        ----------
        db_id : int
            Unique EDB ID for the database.

        Returns
        -------
        .Database
        """
        return Database(cls.__stub.FindById(proto_wrappers.Int64Value(value=db_id)))

    def save_as(self, path: str, version: str = ""):
        """Save the database to a new location and older EDB version.

        Parameters
        ----------
        path : str
            Location for saving the new database file to.
        version : str, default: ""
            EDB version for the new database file. The default is ``""``, in which case
            the new database file is saved for the current version.
        """
        self.__stub.SaveAs(
            database_pb2.SaveAsDatabaseMessage(db=self.msg, new_location=path, version=version)
        )

    @classmethod
    def get_version_by_release(cls, release: str) -> str:
        """Get the EDB version for a given release name.

        Parameters
        ----------
        release : str
           Release name.

        Returns
        -------
        str
           EDB version.
        """
        return cls.__stub.GetVersionByRelease(str_message(release)).value

    @property
    def directory(self) -> str:
        """:obj:`str`: Directory where the database is located."""
        return self.__stub.GetDirectory(self.msg).value

    def get_product_property(self, prod_id: ProductIdType, attr_it: int) -> str:
        """Get a product-specific property value.

        Parameters
        ----------
        prod_id : .ProductIdType
            Product ID.
        attr_it : int
            Attribute ID.

        Returns
        -------
        str
            Property value.
        """
        return self.__stub.GetProductProperty(
            get_product_property_message(self, prod_id, attr_it)
        ).value

    def set_product_property(self, prod_id: ProductIdType, attr_it: int, prop_value: str):
        """Set the product property associated with the given product ID and attribute ID.

        Parameters
        ----------
        prod_id : .ProductIdType
            Product ID.
        attr_it : int
            Attribute ID.
        prop_value : str
            New value for the product property.
        """
        self.__stub.SetProductProperty(
            set_product_property_message(self, prod_id, attr_it, prop_value)
        )

    def get_product_property_ids(self, prod_id: ProductIdType) -> List[int]:
        """Get a list of attribute IDs for a given product property ID.

        Parameters
        ----------
        prod_id : .ProductIdType
            Product ID.

        Returns
        -------
        list[int]
            Attribute IDs associated with the product property.
        """
        attr_ids = self.__stub.GetProductPropertyIds(
            get_product_property_ids_message(self, prod_id)
        ).ids
        return [attr_id for attr_id in attr_ids]

    def import_material_from_control_file(
        self, control_file: str, schema_dir: str | None = None, append: bool = True
    ):
        """Import materials from a control file.

        Parameters
        ----------
        control_file : str
            Full path to the control file.
        schema_dir : str or None, default: None
            Path to the schema directory.
        append : bool, default: True
            Whether to keep existing materials in the database. If ``False``, the
            existing materials in the database are removed.
        """
        self.__stub.ImportMaterialFromControlFile(
            database_pb2.ImportMaterialFromControlFileMessage(
                target=self.msg,
                file=control_file,
                schema_path=schema_dir,
                append=append,
            )
        )

    @property
    def version(self) -> Tuple[int, int]:
        """:obj:`tuple` of (:obj:`int`, :obj:`int`): Version [major, minor] of the database."""
        version_msg = self.__stub.GetVersion(self.msg)
        return version_msg.major.id, version_msg.minor.id

    def scale(self, scale_factor: float):
        """Scale all geometries and their locations uniformly by a positive factor.

        Parameters
        ----------
        scale_factor : float
            Amount to multiply coordinates by.
        """
        self.__stub.Scale(double_property_message(self, scale_factor))

    @property
    def source(self) -> str:
        """:obj:`str`: Name of the source database."""
        return self.__stub.GetSource(self.msg).value

    @source.setter
    def source(self, source: str):
        self.__stub.SetSource(edb_obj_name_message(self, source))

    @property
    def source_version(self) -> str:
        """:obj:`str`: Source version for the database."""
        return self.__stub.GetSourceVersion(self.msg).value

    @source_version.setter
    def source_version(self, source_version: str):
        self.__stub.SetSourceVersion(edb_obj_name_message(self, source_version))

    def copy_cells(self, cells_to_copy: List[Cell]) -> List[Cell]:
        """Copy cells from other databases or this database into this database.

        Parameters
        ----------
        cells_to_copy : list of .Cell
            Cells to copy.

        Returns
        -------
        list of .Cell
            New cells created in this database.
        """
        return Database._map_cell_edb_obj_collection(
            self.__stub.CopyCells(
                database_pb2.CopyCellsMessage(
                    target=self.msg, cells=edb_obj_collection_message(cells_to_copy)
                )
            )
        )

    def _get_definition_objs(
        self, def_class, def_type_enum: DefinitionObjType, bw_def_type_enum: BondwireDefType = None
    ) -> List:
        """Get the definition objects of a given type."""
        def_objs = self.__stub.GetDefinitionObjs(
            database_pb2.GetDefinitionObjsMessage(
                target=self.msg,
                type=def_type_enum.value,
                subtype=bw_def_type_enum.value if bw_def_type_enum is not None else None,
            )
        )
        return map_list(def_objs.items, def_class)

    def _get_bondwire_definition_objs(self, def_class, bw_def_type_enum: BondwireDefType) -> List:
        """Get the bondwire definition objects of a given type."""
        return self._get_definition_objs(
            def_class, DefinitionObjType.BONDWIRE_DEF, bw_def_type_enum
        )

    @property
    def apd_bondwire_defs(self) -> List[ApdBondwireDef]:
        """:obj:`list` of :class:`.ApdBondwireDef`: All APD bondwire definitions in the database."""
        return self._get_bondwire_definition_objs(ApdBondwireDef, BondwireDefType.APD_BONDWIRE_DEF)

    @property
    def jedec4_bondwire_defs(self) -> List[Jedec4BondwireDef]:
        """:obj:`list` of :class:`.Jedec4BondwireDef`: All JEDEC4 bondwire definitions in the database."""
        return self._get_bondwire_definition_objs(
            Jedec4BondwireDef, BondwireDefType.JEDEC4_BONDWIRE_DEF
        )

    @property
    def jedec5_bondwire_defs(self) -> List[Jedec5BondwireDef]:
        """:obj:`list` of:class:`.Jedec5BondwireDef`: All JEDEC5 bondwire definitions in the database."""
        return self._get_bondwire_definition_objs(
            Jedec5BondwireDef, BondwireDefType.JEDEC5_BONDWIRE_DEF
        )

    @property
    def padstack_defs(self) -> List[PadstackDef]:
        """:obj:`list` of :class:`.PadstackDef`: All padstack definitions in the database."""
        return self._get_definition_objs(PadstackDef, DefinitionObjType.PADSTACK_DEF)

    @property
    def package_defs(self) -> List[PackageDef]:
        """:obj:`list` of :class:`.PackageDef`: All package definitions in the database."""
        return self._get_definition_objs(PackageDef, DefinitionObjType.PACKAGE_DEF)

    @property
    def component_defs(self) -> List[ComponentDef]:
        """:obj:`list` of :class:`.ComponentDef`: All component definitions in the database."""
        return self._get_definition_objs(ComponentDef, DefinitionObjType.COMPONENT_DEF)

    @property
    def material_defs(self) -> List[MaterialDef]:
        """:obj:`list` of :class:`.MaterialDef`: All material definitions in the database."""
        return self._get_definition_objs(MaterialDef, DefinitionObjType.MATERIAL_DEF)

    @property
    def dataset_defs(self) -> List[DatasetDef]:
        """:obj:`list` of :class:`.DatasetDef`: All dataset definitions in the database."""
        return self._get_definition_objs(DatasetDef, DefinitionObjType.DATASET_DEF)



"""Triangle 3D data."""
from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ansys.edb.core.geometry.point3d_data import Point3DData


class Triangle3DData:
    """Represents a triangle defined by three 3D points."""

    def __init__(self, point_1: Point3DData, point_2: Point3DData, point_3: Point3DData):
        """Create a 3D triangle.

        Parameters
        ----------
        point_1 : .Point3DData
        point_2 : .Point3DData
        point_3 : .Point3DData
        """
        self._point_1 = point_1
        self._point_2 = point_2
        self._point_3 = point_3

    @property
    def point_1(self) -> Point3DData:
        """:class:`.Point3DData`: First 3D point."""
        return self._point_1

    @point_1.setter
    def point_1(self, point_1: Point3DData):
        self._point_1 = point_1

    @property
    def point_2(self) -> Point3DData:
        """:class:`.Point3DData`: Second 3D point."""
        return self._point_2

    @point_2.setter
    def point_2(self, point_2: Point3DData):
        self._point_2 = point_2

    @property
    def point_3(self) -> Point3DData:
        """:class:`.Point3DData`: Third 3D point."""
        return self._point_3

    @point_3.setter
    def point_3(self, point_3: Point3DData):
        self._point_3 = point_3



"""Die property."""
from __future__ import annotations

from typing import TYPE_CHECKING

if TYPE_CHECKING:
    from ansys.edb.core.typing import ValueLike

from enum import Enum

import ansys.api.edb.v1.die_property_pb2 as die_property_pb2
from ansys.api.edb.v1.die_property_pb2_grpc import DiePropertyServiceStub
import google.protobuf.empty_pb2 as empty_pb2

from ansys.edb.core.inner import ObjBase, messages
from ansys.edb.core.session import StubAccessor, StubType
from ansys.edb.core.utility.value import Value


class DieOrientation(Enum):
    """Enum representing die orientations."""

    CHIP_UP = die_property_pb2.DIE_ORIENTATION_CHIP_UP
    CHIP_DOWN = die_property_pb2.DIE_ORIENTATION_CHIP_DOWN


class DieType(Enum):
    """Enum representing die types."""

    NONE = die_property_pb2.DIE_TYPE_NONE
    FLIPCHIP = die_property_pb2.DIE_TYPE_FLIPCHIP
    WIREBOND = die_property_pb2.DIE_TYPE_WIREBOND


class DieProperty(ObjBase):
    """Represents the properties of a die."""

    __stub: DiePropertyServiceStub = StubAccessor(StubType.die_property)

    @classmethod
    def create(cls) -> DieProperty:
        """
        Create a die property.

        Returns
        -------
        .DieProperty
        """
        return DieProperty(cls.__stub.Create(empty_pb2.Empty()))

    def clone(self) -> DieProperty:
        """
        Clone a die property.

        Returns
        -------
        .DieProperty
        """
        return DieProperty(self.__stub.Clone(messages.edb_obj_message(self)))

    @property
    def die_type(self) -> DieType:
        """:class:`.DieType`: Die type."""
        return DieType(self.__stub.GetDieType(self.msg).die_type)

    @die_type.setter
    def die_type(self, value: DieType):
        self.__stub.SetDieType(messages.set_die_type_message(self, value))

    @property
    def height(self) -> Value:
        """:class:`.Value`: Die height."""
        return Value(self.__stub.GetHeight(messages.edb_obj_message(self)))

    @height.setter
    def height(self, height: ValueLike):
        self.__stub.SetHeight(messages.value_property_message(self, messages.value_message(height)))

    @property
    def die_orientation(self) -> DieOrientation:
        """:class:`.DieOrientation`: Die orientation."""
        return DieOrientation(self.__stub.GetOrientation(self.msg).die_orientation)

    @die_orientation.setter
    def die_orientation(self, value: DieOrientation):
        self.__stub.SetOrientation(messages.set_die_orientation_message(self, value))



"""Primitive classes."""
from __future__ import annotations

from enum import Enum

from ansys.api.edb.v1 import primitive_pb2, primitive_pb2_grpc

from ansys.edb.core.edb_defs import LayoutObjType
from ansys.edb.core.inner import conn_obj, factory, messages, utils
from ansys.edb.core.layer.layer import Layer
from ansys.edb.core.session import StubAccessor, StubType


class PrimitiveType(Enum):
    """Provides an enum representing primitive types."""

    RECTANGLE = primitive_pb2.RECTANGLE
    CIRCLE = primitive_pb2.CIRCLE
    POLYGON = primitive_pb2.POLYGON
    PATH = primitive_pb2.PATH
    BONDWIRE = primitive_pb2.BONDWIRE
    PRIM_PLUGIN = primitive_pb2.PRIM_PLUGIN
    TEXT = primitive_pb2.TEXT
    PATH_3D = primitive_pb2.PATH_3D
    BOARD_BEND = primitive_pb2.BOARD_BEND
    PRIM_INST_COLLECTION = primitive_pb2.PRIM_INST_COLLECTION
    INVALID_TYPE = primitive_pb2.INVALID_TYPE


class Primitive(conn_obj.ConnObj):
    """Represents a primitive object."""

    __stub: primitive_pb2_grpc.PrimitiveServiceStub = StubAccessor(StubType.primitive)
    layout_obj_type = LayoutObjType.PRIMITIVE
    """:class:`.LayoutObjType`: Layout object type of the Primitive class."""

    def cast(self) -> Primitive | None:
        """Cast the primitive object to the correct concrete type.

        Returns
        -------
        .Primitive
        """
        return None if self.is_null else factory.create_primitive(self.msg, self.primitive_type)

    @property
    def primitive_type(self) -> PrimitiveType:
        """:class:`.PrimitiveType`: Primitive type of the primitive.

        This property is read-only.
        """
        return PrimitiveType(self.__stub.GetPrimitiveType(self.msg).type)

    def add_void(self, hole):
        """Add a void to the primitive.

        Parameters
        ----------
        hole : .Primitive
            Void to add.
        """
        self.__stub.AddVoid(
            primitive_pb2.PrimitiveVoidCreationMessage(target=self.msg, hole=hole.msg)
        )

    def set_hfss_prop(self, material: str, solve_inside: bool):
        """Set HFSS properties.

        Parameters
        ----------
        material : str
            Material property name to set.
        solve_inside : bool
            Whether to solve inside.
        """
        self.__stub.SetHfssProp(
            primitive_pb2.PrimitiveHfssPropMessage(
                target=self.msg, material_name=material, solve_inside=solve_inside
            )
        )

    @property
    def layer(self) -> Layer:
        """:class:`.Layer`: Layer that the primitive object is on."""
        layer_msg = self.__stub.GetLayer(self.msg)
        return Layer(layer_msg).cast()

    @layer.setter
    def layer(self, layer: Layer):
        self.__stub.SetLayer(
            primitive_pb2.SetLayerMessage(target=self.msg, layer=messages.layer_ref_message(layer))
        )

    @property
    def is_negative(self) -> bool:
        """:obj:`bool`: Flag indicating if the primitive is negative."""
        return self.__stub.GetIsNegative(self.msg).value

    @is_negative.setter
    def is_negative(self, is_negative: bool):
        self.__stub.SetIsNegative(
            primitive_pb2.SetIsNegativeMessage(target=self.msg, is_negative=is_negative)
        )

    @property
    def is_void(self) -> bool:
        """:obj:`bool`: Flag indicating if a primitive is a void.

        This property is read-only.
        """
        return self.__stub.IsVoid(self.msg).value

    @property
    def has_voids(self) -> bool:
        """:obj:`bool`: Flag indicating if a primitive has voids inside.

        This property is read-only.
        """
        return self.__stub.HasVoids(self.msg).value

    @property
    def voids(self) -> list[Primitive]:
        """:obj:`list` of :class:`.Primitive`: List of void\
        primitive objects inside the primitive.

        This property is read-only.
        """
        return utils.query_lyt_object_collection(
            self, LayoutObjType.PRIMITIVE, self.__stub.Voids, self.__stub.StreamVoids, False
        )

    @property
    def owner(self) -> Primitive:
        """:class:`.Primitive`: Owner of the primitive object.

        This property is read-only.
        """
        return Primitive(self.__stub.GetOwner(self.msg)).cast()

    @property
    def is_parameterized(self) -> bool:
        """:obj:`bool`: Whether the primitive is parametrized.

        This property is read-only.
        """
        return self.__stub.IsParameterized(self.msg).value

    def get_hfss_prop(self) -> tuple[str, bool]:
        """Get HFSS properties.

        Returns
        -------
        tuple of (str, bool)

            Returns a tuple in this format:

            **(material, solve_inside)**

            **material** :  Name of the material property.

            **solve_inside** : Whether to solve inside.
        """
        prop_msg = self.__stub.GetHfssProp(self.msg)
        return prop_msg.material_name, prop_msg.solve_inside

    def remove_hfss_prop(self):
        """Remove HFSS properties."""
        self.__stub.RemoveHfssProp(self.msg)

    @property
    def is_zone_primitive(self) -> bool:
        """:obj:`bool`: Flag indicating if the primitive object is a zone.

        This property is read-only.
        """
        return self.__stub.IsZonePrimitive(self.msg).value

    @property
    def can_be_zone_primitive(self) -> bool:
        """:obj:`bool`: Flag indicating if the primitive can be a zone.

        This property is read-only.
        """
        return True

    def make_zone_primitive(self, zone_id: int):
        """Make the primitive a zone primitive with a zone specified by the provided ID.

        Parameters
        ----------
        zone_id : int
            ID of the zone primitive to use.
        """
        self.__stub.MakeZonePrimitive(messages.int_property_message(self, zone_id))



"""Defines container which gives additional information for RPC methods."""


class _RpcInfo:
    def __init__(
        self,
        read_no_cache=False,
        write_no_buffer=False,
        cache=False,
        buffer=False,
        returns_future=False,
        write_no_cache_invalidation=False,
    ):
        self._read_no_cache = read_no_cache
        self._write_no_buffer = write_no_buffer
        self._cache = cache
        self._buffer = buffer
        self._write_no_cache_invalidation = write_no_cache_invalidation
        self._returns_future = returns_future

    @property
    def is_read(self):
        return self._cache or self._read_no_cache

    @property
    def is_write(self):
        return self._buffer or self._write_no_buffer

    @property
    def can_cache(self):
        return self._cache

    @property
    def can_buffer(self):
        return self._buffer

    @property
    def returns_future(self):
        return self._returns_future

    @property
    def invalidates_cache(self):
        return self.is_write and not self._write_no_cache_invalidation


rpc_information = {
    "ansys.api.edb.v1.ArcDataService": {
        "GetHeight": _RpcInfo(cache=True),
        "GetCenter": _RpcInfo(cache=True),
        "GetMidpoint": _RpcInfo(cache=True),
        "GetRadius": _RpcInfo(cache=True),
        "GetBoundingBox": _RpcInfo(cache=True),
        "GetAngle": _RpcInfo(cache=True),
        "ClosestPoints": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.BoardBendDefService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetBoundaryPrim": _RpcInfo(cache=True),
        "GetBendMiddle": _RpcInfo(cache=True),
        "SetBendMiddle": _RpcInfo(buffer=True),
        "GetRadius": _RpcInfo(cache=True),
        "SetRadius": _RpcInfo(buffer=True),
        "GetAngle": _RpcInfo(cache=True),
        "SetAngle": _RpcInfo(buffer=True),
        "GetBentRegions": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.BondwireService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetMaterial": _RpcInfo(cache=True),
        "SetMaterial": _RpcInfo(buffer=True),
        "GetType": _RpcInfo(cache=True),
        "SetType": _RpcInfo(buffer=True),
        "GetCrossSectionType": _RpcInfo(cache=True),
        "SetCrossSectionType": _RpcInfo(buffer=True),
        "GetCrossSectionHeight": _RpcInfo(cache=True),
        "SetCrossSectionHeight": _RpcInfo(buffer=True),
        "GetDefinitionName": _RpcInfo(cache=True),
        "SetDefinitionName": _RpcInfo(buffer=True),
        "GetStartElevation": _RpcInfo(cache=True),
        "SetStartElevation": _RpcInfo(buffer=True),
        "GetEndElevation": _RpcInfo(cache=True),
        "SetEndElevation": _RpcInfo(buffer=True),
        "GetTraj": _RpcInfo(cache=True),
        "SetTraj": _RpcInfo(buffer=True),
        "GetWidthValue": _RpcInfo(cache=True),
        "SetWidthValue": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.BondwireDefService": {
        "Delete": _RpcInfo(buffer=True),
        "GetName": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.ApdBondwireDefService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetParameters": _RpcInfo(cache=True),
        "SetParameters": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.Jedec4BondwireDefService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetParameters": _RpcInfo(cache=True),
        "SetParameters": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.Jedec5BondwireDefService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetParameters": _RpcInfo(cache=True),
        "SetParameters": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.BundleTerminalService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "Ungroup": _RpcInfo(buffer=True),
        "GetTerminals": _RpcInfo(read_no_cache=True),
        "StreamTerminals": _RpcInfo(read_no_cache=True),
    },
    "ansys.api.edb.v1.CellService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetLayout": _RpcInfo(cache=True),
        "Find": _RpcInfo(cache=True),
        "Delete": _RpcInfo(buffer=True),
        "GetDatabase": _RpcInfo(cache=True),
        "IsFootprint": _RpcInfo(cache=True),
        "IsBlackBox": _RpcInfo(cache=True),
        "SetBlackBox": _RpcInfo(buffer=True),
        "GetSuppressPads": _RpcInfo(cache=True),
        "SetSuppressPads": _RpcInfo(buffer=True),
        "GetAntiPadsAlwaysOn": _RpcInfo(cache=True),
        "SetAntiPadsAlwaysOn": _RpcInfo(buffer=True),
        "GetAntiPadsOption": _RpcInfo(cache=True),
        "SetAntiPadsOption": _RpcInfo(buffer=True),
        "IsSymbolicFootprint": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetDesignMode": _RpcInfo(cache=True),
        "SetDesignMode": _RpcInfo(buffer=True),
        "GetHfssExtentInfo": _RpcInfo(cache=True),
        "SetHfssExtentInfo": _RpcInfo(buffer=True),
        "GetTemperatureSettings": _RpcInfo(cache=True),
        "SetTemperatureSettings": _RpcInfo(buffer=True),
        "GetProductPropertyIds": _RpcInfo(cache=True),
        "GetProductProperty": _RpcInfo(cache=True),
        "SetProductProperty": _RpcInfo(buffer=True),
        "DeleteSimulationSetup": _RpcInfo(buffer=True),
        "GetSimulationSetups": _RpcInfo(read_no_cache=True),
        "StreamSimulationSetups": _RpcInfo(read_no_cache=True),
        "GenerateAutoHFSSRegions": _RpcInfo(buffer=True),
        "GenerateViaSmartBox": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.CellInstanceService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "CreateWithComponent": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetReferenceLayout": _RpcInfo(cache=True),
        "GetIs3DPlacement": _RpcInfo(cache=True),
        "Set3DPlacement": _RpcInfo(buffer=True),
        "Get3DTransform": _RpcInfo(cache=True),
        "Set3DTransform": _RpcInfo(buffer=True),
        "GetParameterOverride": _RpcInfo(cache=True),
        "SetParameterOverride": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.CircleService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "Render": _RpcInfo(cache=True),
        "GetParameters": _RpcInfo(cache=True),
        "SetParameters": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.ComponentDefService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetName": _RpcInfo(cache=True),
        "SetFootprintCell": _RpcInfo(buffer=True),
        "GetFootprintCell": _RpcInfo(cache=True),
        "GetComponentModels": _RpcInfo(read_no_cache=True),
        "StreamComponentModels": _RpcInfo(read_no_cache=True),
        "GetComponentPins": _RpcInfo(read_no_cache=True),
        "StreamComponentPins": _RpcInfo(read_no_cache=True),
        "AddComponentModel": _RpcInfo(buffer=True),
        "RemoveComponentModel": _RpcInfo(buffer=True),
        "ReorderPins": _RpcInfo(buffer=True),
        "RemovePin": _RpcInfo(buffer=True),
        "GetProductProperty": _RpcInfo(cache=True),
        "SetProductProperty": _RpcInfo(buffer=True),
        "GetProductPropertyIds": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.ComponentGroupService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetNumberOfPins": _RpcInfo(cache=True),
        "GetComponentProperty": _RpcInfo(cache=True),
        "SetComponentProperty": _RpcInfo(buffer=True),
        "GetComponentType": _RpcInfo(cache=True),
        "SetComponentType": _RpcInfo(buffer=True),
        "FindByDef": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.ComponentModelService": {
        "SetReferenceFile": _RpcInfo(buffer=True),
        "GetReferenceFile": _RpcInfo(cache=True),
        "FindByName": _RpcInfo(cache=True),
        "FindById": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "GetType": _RpcInfo(cache=True),
        "GetId": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.NPortComponentModelService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True)
    },
    "ansys.api.edb.v1.DynamicLinkComponentModelService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "SetDesignName": _RpcInfo(buffer=True),
        "GetDesignName": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.ComponentPinService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "FindByName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetName": _RpcInfo(cache=True),
        "GetNumber": _RpcInfo(cache=True),
        "GetComponentDef": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.ComponentPropertyService": {
        "Clone": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetPackageMountingOffset": _RpcInfo(cache=True),
        "SetPackageMountingOffset": _RpcInfo(buffer=True),
        "GetPackageDef": _RpcInfo(cache=True),
        "SetPackageDef": _RpcInfo(buffer=True),
        "GetModel": _RpcInfo(cache=True),
        "SetModel": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.ConnectableService": {
        "GetObjType": _RpcInfo(cache=True),
        "FindByIdAndType": _RpcInfo(cache=True),
        "GetId": _RpcInfo(cache=True),
        "GetComponent": _RpcInfo(cache=True),
        "GetGroup": _RpcInfo(cache=True),
        "SetGroup": _RpcInfo(buffer=True),
        "GetNet": _RpcInfo(cache=True),
        "SetNet": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.DatabaseService": {
        "IsReadOnly": _RpcInfo(cache=True),
        "GetTopCircuits": _RpcInfo(cache=True),
        "GetId": _RpcInfo(cache=True),
        "FindById": _RpcInfo(cache=True),
        "GetVersionByRelease": _RpcInfo(cache=True),
        "GetDirectory": _RpcInfo(cache=True),
        "GetProductProperty": _RpcInfo(cache=True),
        "SetProductProperty": _RpcInfo(buffer=True),
        "GetProductPropertyIds": _RpcInfo(cache=True),
        "GetVersion": _RpcInfo(cache=True),
        "Scale": _RpcInfo(buffer=True),
        "GetSource": _RpcInfo(cache=True),
        "SetSource": _RpcInfo(buffer=True),
        "GetSourceVersion": _RpcInfo(cache=True),
        "SetSourceVersion": _RpcInfo(buffer=True),
        "GetDefinitionObjs": _RpcInfo(cache=True),
        "TopCircuitCells": _RpcInfo(cache=True),
        "GetCircuits": _RpcInfo(cache=True),
        "GetFootprints": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.DatasetDefService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetData": _RpcInfo(cache=True),
        "SetData": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.DebyeModelService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetFrequencyRange": _RpcInfo(cache=True),
        "SetFrequencyRange": _RpcInfo(buffer=True),
        "GetRelativePermitivityAtHighLowFrequency": _RpcInfo(cache=True),
        "SetRelativePermitivityAtHighLowFrequency": _RpcInfo(buffer=True),
        "IsRelativePermitivityEnabledAtOpticalFrequency": _RpcInfo(cache=True),
        "SetRelativePermitivityEnabledAtOpticalFrequency": _RpcInfo(buffer=True),
        "GetRelativePermitivityAtOpticalFrequency": _RpcInfo(cache=True),
        "SetRelativePermitivityAtOpticalFrequency": _RpcInfo(buffer=True),
        "UseDCConductivity": _RpcInfo(cache=True),
        "SetUseDCConductivity": _RpcInfo(buffer=True),
        "GetDCConductivity": _RpcInfo(cache=True),
        "SetDCConductivity": _RpcInfo(buffer=True),
        "GetLossTangentAtHighLowFrequency": _RpcInfo(cache=True),
        "SetLossTangentAtHighLowFrequency": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.DielectricMaterialModelService": {"GetType": _RpcInfo(cache=True)},
    "ansys.api.edb.v1.DiePropertyService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "Clone": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetDieType": _RpcInfo(cache=True),
        "SetDieType": _RpcInfo(buffer=True),
        "GetHeight": _RpcInfo(cache=True),
        "SetHeight": _RpcInfo(buffer=True),
        "GetOrientation": _RpcInfo(cache=True),
        "SetOrientation": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.DifferentialPairService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetDifferentialPair": _RpcInfo(cache=True),
        "SetDifferentialPair": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.DjordjecvicSarkarModelService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetFrequency": _RpcInfo(cache=True),
        "SetFrequency": _RpcInfo(buffer=True),
        "GetRelativePermitivityAtFrequency": _RpcInfo(cache=True),
        "SetRelativePermitivityAtFrequency": _RpcInfo(buffer=True),
        "GetLossTangentAtFrequency": _RpcInfo(cache=True),
        "SetLossTangentAtFrequency": _RpcInfo(buffer=True),
        "GetHighFrequencyCorner": _RpcInfo(cache=True),
        "SetHighFrequencyCorner": _RpcInfo(buffer=True),
        "UseDCRelativePermitivity": _RpcInfo(cache=True),
        "SetUseDCRelativePermitivity": _RpcInfo(buffer=True),
        "GetDCRelativePermitivity": _RpcInfo(cache=True),
        "SetDCRelativePermitivity": _RpcInfo(buffer=True),
        "GetDCConductivity": _RpcInfo(cache=True),
        "SetDCConductivity": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.EDBErrorManagerService": {"GetErrors": _RpcInfo(read_no_cache=True)},
    "ansys.api.edb.v1.EdgeService": {
        "GetEdgeType": _RpcInfo(cache=True),
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetParameters": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.EdgeTerminalService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetEdges": _RpcInfo(read_no_cache=True),
        "StreamEdges": _RpcInfo(read_no_cache=True),
        "SetEdges": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.ExtendedNetService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "RemoveNet": _RpcInfo(buffer=True),
        "AddNet": _RpcInfo(buffer=True),
        "RemoveAllNets": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.GroupService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "AddMember": _RpcInfo(buffer=True),
        "RemoveMember": _RpcInfo(buffer=True),
        "Ungroup": _RpcInfo(buffer=True),
        "GetMembers": _RpcInfo(read_no_cache=True),
        "StreamMembers": _RpcInfo(read_no_cache=True),
        "GetGroupType": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.HFSSPIGeneralSettingsService": {
        "GetPISliderPos": _RpcInfo(cache=True),
        "SetPISliderPos": _RpcInfo(buffer=True),
        "GetHFSSPIModelType": _RpcInfo(cache=True),
        "SetHFSSPIModelType": _RpcInfo(buffer=True),
        "GetMinPlaneAreaToMesh": _RpcInfo(cache=True),
        "SetMinPlaneAreaToMesh": _RpcInfo(buffer=True),
        "GetMinVoidAreaToMesh": _RpcInfo(cache=True),
        "SetMinVoidAreaToMesh": _RpcInfo(buffer=True),
        "GetSnapLengthThreshold": _RpcInfo(cache=True),
        "SetSnapLengthThreshold": _RpcInfo(buffer=True),
        "GetIncludeEnhancedBondWireModeling": _RpcInfo(cache=True),
        "SetIncludeEnhancedBondWireModeling": _RpcInfo(buffer=True),
        "GetSurfaceRoughnessModel": _RpcInfo(cache=True),
        "SetSurfaceRoughnessModel": _RpcInfo(buffer=True),
        "GetRMSSurfaceRoughness": _RpcInfo(cache=True),
        "SetRMSSurfaceRoughness": _RpcInfo(buffer=True),
        "GetPerformERC": _RpcInfo(cache=True),
        "SetPerformERC": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HFSSPINetProcessingSettingsService": {
        "GetAutoSelectNetsForSimulation": _RpcInfo(cache=True),
        "SetAutoSelectNetsForSimulation": _RpcInfo(buffer=True),
        "GetIgnoreDummyNetsForSelectedNets": _RpcInfo(cache=True),
        "SetIgnoreDummyNetsForSelectedNets": _RpcInfo(buffer=True),
        "GetIncludeNets": _RpcInfo(cache=True),
        "SetIncludeNets": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HFSSPIPowerGroundNetsService": {
        "GetImprovedLossModel": _RpcInfo(cache=True),
        "SetImprovedLossModel": _RpcInfo(buffer=True),
        "GetAutoDetectIgnoreSmallHolesMinDiameter": _RpcInfo(cache=True),
        "SetAutoDetectIgnoreSmallHolesMinDiameter": _RpcInfo(buffer=True),
        "GetIgnoreSmallHolesMinDiameter": _RpcInfo(cache=True),
        "SetIgnoreSmallHolesMinDiameter": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HFSSPISignalNetsSettingsService": {
        "GetSignalNetsErrorTolerance": _RpcInfo(cache=True),
        "SetSignalNetsErrorTolerance": _RpcInfo(buffer=True),
        "GetSignalNetsConductorModeling": _RpcInfo(cache=True),
        "SetSignalNetsConductorModeling": _RpcInfo(buffer=True),
        "GetSignalNetsIncludeImprovedLossHandling": _RpcInfo(cache=True),
        "SetSignalNetsIncludeImprovedLossHandling": _RpcInfo(buffer=True),
        "GetSignalNetsIncludeImprovedDielectricFillRefinement": _RpcInfo(cache=True),
        "SetSignalNetsIncludeImprovedDielectricFillRefinement": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HFSSGeneralSettingsService": {
        "GetSingleFrequencyAdaptiveSolution": _RpcInfo(cache=True),
        "SetSingleFrequencyAdaptiveSolution": _RpcInfo(buffer=True),
        "GetMultiFrequencyAdaptiveSolution": _RpcInfo(cache=True),
        "SetMultiFrequencyAdaptiveSolution": _RpcInfo(buffer=True),
        "GetBroadbandFrequencyAdaptiveSolution": _RpcInfo(cache=True),
        "SetBroadbandFrequencyAdaptiveSolution": _RpcInfo(buffer=True),
        "GetSaveFieldsFlag": _RpcInfo(cache=True),
        "SetSaveFieldsFlag": _RpcInfo(buffer=True),
        "GetUseMeshRegion": _RpcInfo(cache=True),
        "SetUseMeshRegion": _RpcInfo(buffer=True),
        "GetMeshRegionName": _RpcInfo(cache=True),
        "SetMeshRegionName": _RpcInfo(buffer=True),
        "GetUseParallelRefinement": _RpcInfo(cache=True),
        "SetUseParallelRefinement": _RpcInfo(buffer=True),
        "GetAdaptType": _RpcInfo(cache=True),
        "SetAdaptType": _RpcInfo(buffer=True),
        "GetSaveRadFieldsOnlyFlag": _RpcInfo(cache=True),
        "SetSaveRadFieldsOnlyFlag": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HFSSOptionsSettingsService": {
        "GetMaxRefinementPerPass": _RpcInfo(cache=True),
        "SetMaxRefinementPerPass": _RpcInfo(buffer=True),
        "GetMinPasses": _RpcInfo(cache=True),
        "SetMinPasses": _RpcInfo(buffer=True),
        "GetMinConvergedPasses": _RpcInfo(cache=True),
        "SetMinConvergedPasses": _RpcInfo(buffer=True),
        "GetUseMaxRefinement": _RpcInfo(cache=True),
        "SetUseMaxRefinement": _RpcInfo(buffer=True),
        "GetBasisFunctionOrder": _RpcInfo(cache=True),
        "SetBasisFunctionOrder": _RpcInfo(buffer=True),
        "GetSolverTypeOrder": _RpcInfo(cache=True),
        "SetSolverTypeOrder": _RpcInfo(buffer=True),
        "GetRelativeResidual": _RpcInfo(cache=True),
        "SetRelativeResidual": _RpcInfo(buffer=True),
        "GetUseShellElements": _RpcInfo(cache=True),
        "SetUseShellElements": _RpcInfo(buffer=True),
        "GetEnhancedLowFrequencyAccuracy": _RpcInfo(cache=True),
        "SetEnhancedLowFrequencyAccuracy": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HFSSAdvancedSettingsService": {
        "GetICModeAutoResolution": _RpcInfo(cache=True),
        "SetICModeAutoResolution": _RpcInfo(buffer=True),
        "GetICModeLength": _RpcInfo(cache=True),
        "SetICModeLength": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HFSSAdvancedMeshingSettingsService": {
        "GetLayerAlignment": _RpcInfo(cache=True),
        "SetLayerAlignment": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HFSSSolverSettingsService": {
        "GetMaxDeltaZ0": _RpcInfo(cache=True),
        "SetMaxDeltaZ0": _RpcInfo(buffer=True),
        "GetSetTrianglesForWaveport": _RpcInfo(cache=True),
        "SetSetTrianglesForWaveport": _RpcInfo(buffer=True),
        "GetMinTrianglesForWavePort": _RpcInfo(cache=True),
        "SetMinTrianglesForWavePort": _RpcInfo(buffer=True),
        "GetMaxTrianglesForWavePort": _RpcInfo(cache=True),
        "SetMaxTrianglesForWavePort": _RpcInfo(buffer=True),
        "GetIntraPlaneCouplingEnabled": _RpcInfo(cache=True),
        "SetIntraPlaneCouplingEnabled": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.DCRSettingsService": {
        "GetMaxPasses": _RpcInfo(cache=True),
        "SetMaxPasses": _RpcInfo(buffer=True),
        "GetMinPasses": _RpcInfo(cache=True),
        "SetMinPasses": _RpcInfo(buffer=True),
        "GetMinConvergedPasses": _RpcInfo(cache=True),
        "SetMinConvergedPasses": _RpcInfo(buffer=True),
        "GetPercentError": _RpcInfo(cache=True),
        "SetPercentError": _RpcInfo(buffer=True),
        "GetPercentRefinementPerPass": _RpcInfo(cache=True),
        "SetPercentRefinementPerPass": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HfssSimulationSetupService": {
        "GetMeshOperations": _RpcInfo(cache=True),
        "SetMeshOperations": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.HierarchyObjectService": {
        "GetTransform": _RpcInfo(cache=True),
        "SetTransform": _RpcInfo(buffer=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetComponent": _RpcInfo(cache=True),
        "GetPlacementLayer": _RpcInfo(cache=True),
        "SetPlacementLayer": _RpcInfo(buffer=True),
        "GetLocation": _RpcInfo(cache=True),
        "SetLocation": _RpcInfo(buffer=True),
        "GetSolveIndependentPreference": _RpcInfo(cache=True),
        "SetSolveIndependentPreference": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.ICComponentPropertyService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "SetSolderBallProperty": _RpcInfo(buffer=True),
        "GetSolderBallProperty": _RpcInfo(cache=True),
        "SetDieProperty": _RpcInfo(buffer=True),
        "GetDieProperty": _RpcInfo(cache=True),
        "SetPortProperty": _RpcInfo(buffer=True),
        "GetPortProperty": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.InstArrayService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetXAxis": _RpcInfo(cache=True),
        "SetXAxis": _RpcInfo(buffer=True),
        "GetYAxis": _RpcInfo(cache=True),
        "SetYAxis": _RpcInfo(buffer=True),
        "GetXCount": _RpcInfo(cache=True),
        "SetXCount": _RpcInfo(buffer=True),
        "GetYCount": _RpcInfo(cache=True),
        "SetYCount": _RpcInfo(buffer=True),
        "Decompose": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.IOComponentPropertyService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "SetSolderBallProperty": _RpcInfo(buffer=True),
        "GetSolderBallProperty": _RpcInfo(cache=True),
        "SetPortProperty": _RpcInfo(buffer=True),
        "GetPortProperty": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.LayerService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetLayerType": _RpcInfo(cache=True),
        "SetLayerType": _RpcInfo(buffer=True),
        "IsViaLayer": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "Clone": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetLayerId": _RpcInfo(cache=True),
        "GetTopBottomAssociation": _RpcInfo(cache=True),
        "SetTopBottomAssociation": _RpcInfo(buffer=True),
        "GetColor": _RpcInfo(cache=True),
        "SetColor": _RpcInfo(buffer=True),
        "GetVisibilityMask": _RpcInfo(cache=True),
        "SetVisibilityMask": _RpcInfo(buffer=True),
        "GetLocked": _RpcInfo(cache=True),
        "SetLocked": _RpcInfo(buffer=True),
        "GetTransparency": _RpcInfo(cache=True),
        "SetTransparency": _RpcInfo(buffer=True),
        "GetDrawOverride": _RpcInfo(cache=True),
        "SetDrawOverride": _RpcInfo(buffer=True),
        "GetProductProperty": _RpcInfo(cache=True),
        "SetProductProperty": _RpcInfo(buffer=True),
        "GetProductPropertyIds": _RpcInfo(cache=True),
        "IsInZone": _RpcInfo(cache=True),
        "SetIsInZone": _RpcInfo(buffer=True),
        "GetZones": _RpcInfo(cache=True),
        "GetZone": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.LayerCollectionService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "Clone": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetMode": _RpcInfo(cache=True, write_no_cache_invalidation=True),
        "SetMode": _RpcInfo(buffer=True),
        "AddLayers": _RpcInfo(buffer=True),
        "AddLayer": _RpcInfo(buffer=True, returns_future=True),
        "IsValid": _RpcInfo(cache=True),
        "FindByName": _RpcInfo(cache=True),
        "GetTopBottomStackupLayers": _RpcInfo(cache=True),
        "GetLayers": _RpcInfo(read_no_cache=True),
        "StreamLayers": _RpcInfo(read_no_cache=True),
        "GetProductProperty": _RpcInfo(cache=True),
        "SetProductProperty": _RpcInfo(buffer=True),
        "GetProductPropertyIds": _RpcInfo(cache=True),
        "MergeDielectrics": _RpcInfo(buffer=True, returns_future=True),
        "GetZoneIds": _RpcInfo(cache=True),
        "GetZoneName": _RpcInfo(cache=True),
        "SetZoneName": _RpcInfo(buffer=True),
        "RemoveZone": _RpcInfo(buffer=True),
        "AddZoneToLayer": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.LayerMapService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "Clear": _RpcInfo(buffer=True),
        "SetMapping": _RpcInfo(buffer=True),
        "GetMappingForward": _RpcInfo(cache=True),
        "GetMappingBackward": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.LayoutService": {
        "GetCell": _RpcInfo(cache=True),
        "GetLayerCollection": _RpcInfo(cache=True),
        "SetLayerCollection": _RpcInfo(buffer=True),
        "GetItems": _RpcInfo(read_no_cache=True),
        "StreamItems": _RpcInfo(read_no_cache=True),
        "GetExpandedExtentFromNets": _RpcInfo(cache=True),
        "ConvertPrimitivesToVias": _RpcInfo(buffer=True),
        "ArePortReferenceTerminalsConnected": _RpcInfo(cache=True),
        "GetZonePrimitives": _RpcInfo(read_no_cache=True),
        "StreamZonePrimitives": _RpcInfo(read_no_cache=True),
        "SetFixedZonePrimitives": _RpcInfo(buffer=True),
        "GetFixedZonePrimitive": _RpcInfo(cache=True),
        "GetBoardBendDefs": _RpcInfo(read_no_cache=True),
        "StreamBoardBendDefs": _RpcInfo(read_no_cache=True),
        "GetLayoutInstance": _RpcInfo(cache=True),
        "CompressPrimitives": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.LayoutComponentService": {
        "ExportLayoutComponent": _RpcInfo(write_no_cache_invalidation=True),
        "ImportLayoutComponent": _RpcInfo(write_no_cache_invalidation=True),
        "GetCellInstance": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.LayoutInstanceService": {
        "QueryLayoutObjInstances": _RpcInfo(cache=True),
        "StreamLayoutObjInstancesQuery": _RpcInfo(read_no_cache=True),
        "GetLayoutObjInstanceInContext": _RpcInfo(cache=True),
        "GetConnectedObjects": _RpcInfo(read_no_cache=True),
        "StreamConnectedObjects": _RpcInfo(read_no_cache=True),
    },
    "ansys.api.edb.v1.LayoutInstanceContextService": {
        "GetLayout": _RpcInfo(cache=True),
        "GetBBox": _RpcInfo(cache=True),
        "IsTopOrBlackBox": _RpcInfo(cache=True),
        "GetTopOrBlackBox": _RpcInfo(cache=True),
        "GetPlacementElevation": _RpcInfo(cache=True),
        "Is3DPlacement": _RpcInfo(cache=True),
        "GetTransformation": _RpcInfo(cache=True),
        "GetTransformationBetweenContexts": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.LayoutObjService": {
        "GetLayout": _RpcInfo(cache=True),
        "Delete": _RpcInfo(buffer=True),
        "GetProductProperty": _RpcInfo(cache=True),
        "SetProductProperty": _RpcInfo(buffer=True),
        "GetProductPropertyIds": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.LayoutObjInstanceService": {
        "GetLayers": _RpcInfo(cache=True),
        "StreamLayers": _RpcInfo(read_no_cache=True),
        "GetGeometries": _RpcInfo(cache=True),
        "GetContext": _RpcInfo(cache=True),
        "GetLayoutInstanceContext": _RpcInfo(cache=True),
        "GetLayoutObj": _RpcInfo(cache=True),
        "GetBBox": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.LayoutObjInstance2DGeometryService": {
        "IsNegative": _RpcInfo(cache=True),
        "GetPolygonData": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.LayoutObjInstance3DGeometryService": {
        "GetTesselationData": _RpcInfo(cache=True)
    },
    "ansys.api.edb.v1.LayoutObjInstanceGeometryService": {
        "GetMaterial": _RpcInfo(cache=True),
        "GetColor": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.MaterialDefService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "SetProperty": _RpcInfo(buffer=True),
        "FindByName": _RpcInfo(cache=True),
        "Delete": _RpcInfo(buffer=True),
        "GetProperty": _RpcInfo(cache=True),
        "GetAllProperties": _RpcInfo(cache=True),
        "RemoveProperty": _RpcInfo(buffer=True),
        "GetName": _RpcInfo(cache=True),
        "GetDielectricMaterialModel": _RpcInfo(cache=True),
        "SetDielectricMaterialModel": _RpcInfo(buffer=True),
        "GetDimensions": _RpcInfo(cache=True),
        "SetThermalModifier": _RpcInfo(buffer=True),
        "SetAnisotropicThermalModifier": _RpcInfo(buffer=True),
        "GetThermalModifier": _RpcInfo(cache=True),
        "GetAnisotropicThermalModifier": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.MaterialPropertyThermalModifierService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetQuadraticModelParams": _RpcInfo(cache=True),
        "GetThermalModifierExpression": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.McadModelService": {
        "CreateStride": _RpcInfo(buffer=True, returns_future=True),
        "CreateHfss": _RpcInfo(buffer=True, returns_future=True),
        "Create3dComp": _RpcInfo(buffer=True, returns_future=True),
        "IsMcad": _RpcInfo(cache=True),
        "IsMcadStride": _RpcInfo(cache=True),
        "IsMcadHfss": _RpcInfo(cache=True),
        "IsMcad3dComp": _RpcInfo(cache=True),
        "GetOrigin": _RpcInfo(cache=True),
        "SetOrigin": _RpcInfo(buffer=True),
        "GetRotation": _RpcInfo(cache=True),
        "SetRotation": _RpcInfo(buffer=True),
        "GetScale": _RpcInfo(cache=True),
        "SetScale": _RpcInfo(buffer=True),
        "GetMaterial": _RpcInfo(cache=True),
        "SetMaterial": _RpcInfo(buffer=True),
        "GetVisible": _RpcInfo(cache=True),
        "SetVisible": _RpcInfo(buffer=True),
        "GetModeled": _RpcInfo(cache=True),
        "SetModeled": _RpcInfo(buffer=True),
        "GetCellInst": _RpcInfo(cache=True),
        "GetPartCount": _RpcInfo(cache=True),
        "GetPartName": _RpcInfo(cache=True),
        "GetPartIndex": _RpcInfo(cache=True),
        "GetModelName": _RpcInfo(cache=True),
        "GetDesignName": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.ModelService": {
        "Clone": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True)
    },
    "ansys.api.edb.v1.MultipoleDebyeModelService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetParameters": _RpcInfo(cache=True),
        "SetParameters": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.NetService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetIsPowerGround": _RpcInfo(cache=True),
        "SetIsPowerGround": _RpcInfo(buffer=True),
        "GetLayoutObjects": _RpcInfo(read_no_cache=True),
        "StreamLayoutObjects": _RpcInfo(read_no_cache=True),
    },
    "ansys.api.edb.v1.NetlistModelService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetNetlist": _RpcInfo(cache=True),
        "SetNetlist": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.NetClassService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetDescription": _RpcInfo(cache=True),
        "SetDescription": _RpcInfo(buffer=True),
        "IsPowerGround": _RpcInfo(cache=True),
        "AddNet": _RpcInfo(buffer=True),
        "RemoveNet": _RpcInfo(buffer=True),
        "ContainsNet": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.PackageDefService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "Delete": _RpcInfo(buffer=True),
        "FindByName": _RpcInfo(cache=True),
        "FindByEDBUId": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetExteriorBoundary": _RpcInfo(cache=True),
        "SetExteriorBoundary": _RpcInfo(buffer=True),
        "GetHeight": _RpcInfo(cache=True),
        "SetHeight": _RpcInfo(buffer=True),
        "GetOperatingPower": _RpcInfo(cache=True),
        "SetOperatingPower": _RpcInfo(buffer=True),
        "GetMaximumPower": _RpcInfo(cache=True),
        "SetMaximumPower": _RpcInfo(buffer=True),
        "GetTherm_Cond": _RpcInfo(cache=True),
        "SetTherm_Cond": _RpcInfo(buffer=True),
        "GetTheta_JB": _RpcInfo(cache=True),
        "SetTheta_JB": _RpcInfo(buffer=True),
        "GetTheta_JC": _RpcInfo(cache=True),
        "SetTheta_JC": _RpcInfo(buffer=True),
        "GetHeatSink": _RpcInfo(cache=True),
        "SetHeatSink": _RpcInfo(buffer=True),
        "GetProductProperty": _RpcInfo(cache=True),
        "SetProductProperty": _RpcInfo(buffer=True),
        "GetProductPropertyIds": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.PadstackDefService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "Delete": _RpcInfo(buffer=True),
        "FindByName": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "GetData": _RpcInfo(cache=True),
        "SetData": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.PadstackDefDataService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetMaterial": _RpcInfo(cache=True),
        "SetMaterial": _RpcInfo(buffer=True),
        "GetLayerNames": _RpcInfo(cache=True),
        "GetLayerIds": _RpcInfo(cache=True),
        "AddLayers": _RpcInfo(buffer=True),
        "GetPadParameters": _RpcInfo(cache=True),
        "SetPadParameters": _RpcInfo(buffer=True),
        "GetHoleRange": _RpcInfo(cache=True),
        "SetHoleRange": _RpcInfo(buffer=True),
        "GetPlatingPercentage": _RpcInfo(cache=True),
        "SetPlatingPercentage": _RpcInfo(buffer=True),
        "GetSolderBallShape": _RpcInfo(cache=True),
        "SetSolderBallShape": _RpcInfo(buffer=True),
        "GetSolderBallPlacement": _RpcInfo(cache=True),
        "SetSolderBallPlacement": _RpcInfo(buffer=True),
        "GetSolderBallParam": _RpcInfo(cache=True),
        "SetSolderBallParam": _RpcInfo(buffer=True),
        "GetSolderBallMaterial": _RpcInfo(cache=True),
        "SetSolderBallMaterial": _RpcInfo(buffer=True),
        "GetConnectionPt": _RpcInfo(cache=True),
        "SetConnectionPt": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.PadstackInstanceService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetPadstackDef": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetPositionAndRotation": _RpcInfo(cache=True),
        "SetPositionAndRotation": _RpcInfo(buffer=True),
        "GetLayerRange": _RpcInfo(cache=True),
        "SetLayerRange": _RpcInfo(buffer=True),
        "GetSolderBallLayer": _RpcInfo(cache=True),
        "SetSolderBallLayer": _RpcInfo(buffer=True),
        "GetLayerMap": _RpcInfo(cache=True),
        "SetLayerMap": _RpcInfo(buffer=True),
        "GetHoleOverrides": _RpcInfo(cache=True),
        "SetHoleOverrides": _RpcInfo(buffer=True),
        "GetIsLayoutPin": _RpcInfo(cache=True),
        "SetIsLayoutPin": _RpcInfo(buffer=True),
        "GetBackDrillType": _RpcInfo(cache=True),
        "GetBackDrillByLayer": _RpcInfo(cache=True),
        "GetBackDrillByDepth": _RpcInfo(cache=True),
        "SetBackDrillByLayer": _RpcInfo(buffer=True),
        "SetBackDrillByDepth": _RpcInfo(buffer=True),
        "GetPadstackInstanceTerminal": _RpcInfo(cache=True),
        "IsInPinGroup": _RpcInfo(cache=True),
        "GetPinGroups": _RpcInfo(read_no_cache=True),
        "StreamPinGroups": _RpcInfo(read_no_cache=True),
    },
    "ansys.api.edb.v1.PadstackInstanceTerminalService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetParameters": _RpcInfo(cache=True),
        "SetParameters": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.PathService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "Render": _RpcInfo(cache=True),
        "GetPolygonData": _RpcInfo(cache=True),
        "GetCenterLine": _RpcInfo(cache=True),
        "SetCenterLine": _RpcInfo(buffer=True),
        "GetEndCapStyle": _RpcInfo(cache=True),
        "SetEndCapStyle": _RpcInfo(buffer=True),
        "GetClipInfo": _RpcInfo(cache=True),
        "SetClipInfo": _RpcInfo(buffer=True),
        "GetCornerStyle": _RpcInfo(cache=True),
        "SetCornerStyle": _RpcInfo(buffer=True),
        "GetWidth": _RpcInfo(cache=True),
        "SetWidth": _RpcInfo(buffer=True),
        "GetMiterRatio": _RpcInfo(cache=True),
        "SetMiterRatio": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.PinGroupService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetName": _RpcInfo(cache=True),
        "AddPins": _RpcInfo(buffer=True),
        "RemovePins": _RpcInfo(buffer=True),
        "GetPinGroupTerminal": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.PinGroupTerminalService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetPinGroup": _RpcInfo(cache=True),
        "SetPinGroup": _RpcInfo(buffer=True),
        "GetLayer": _RpcInfo(cache=True),
        "SetLayer": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.PinPairModelService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetRlc": _RpcInfo(cache=True),
        "SetRlc": _RpcInfo(buffer=True),
        "DeleteRlc": _RpcInfo(buffer=True),
        "GetPinPairs": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.PointDataService": {
        "Rotate": _RpcInfo(cache=True),
        "ClosestPoint": _RpcInfo(cache=True),
        "Distance": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.PointTerminalService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetParameters": _RpcInfo(cache=True),
        "SetParameters": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.PolygonService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetPolygonData": _RpcInfo(cache=True),
        "SetPolygonData": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.PolygonDataService": {
        "GetNormalizedPoints": _RpcInfo(cache=True),
        "IsCircle": _RpcInfo(cache=True),
        "IsBox": _RpcInfo(cache=True),
        "HasSelfIntersections": _RpcInfo(cache=True),
        "RemoveSelfIntersections": _RpcInfo(cache=True),
        "IsConvex": _RpcInfo(cache=True),
        "GetArea": _RpcInfo(cache=True),
        "Transform": _RpcInfo(cache=True),
        "GetBBox": _RpcInfo(cache=True),
        "GetStreamedBBox": _RpcInfo(read_no_cache=True),
        "GetConvexHull": _RpcInfo(cache=True),
        "RemoveArcs": _RpcInfo(cache=True),
        "Defeature": _RpcInfo(cache=True),
        "GetBoundingCircle": _RpcInfo(cache=True),
        "IsInside": _RpcInfo(cache=True),
        "CircleIntersectsPolygon": _RpcInfo(cache=True),
        "GetIntersectionType": _RpcInfo(cache=True),
        "GetClosestPoints": _RpcInfo(cache=True),
        "GetUnion": _RpcInfo(cache=True),
        "GetIntersection": _RpcInfo(cache=True),
        "Subtract": _RpcInfo(cache=True),
        "Xor": _RpcInfo(cache=True),
        "Expand": _RpcInfo(cache=True),
        "Get2DAlphaShape": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.PortPropertyService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "Clone": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetReferenceHeight": _RpcInfo(cache=True),
        "SetReferenceHeight": _RpcInfo(buffer=True),
        "GetReferenceSizeAuto": _RpcInfo(cache=True),
        "SetReferenceSizeAuto": _RpcInfo(buffer=True),
        "GetReferenceSize": _RpcInfo(cache=True),
        "SetReferenceSize": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.PrimitiveService": {
        "GetPrimitiveType": _RpcInfo(cache=True),
        "AddVoid": _RpcInfo(buffer=True),
        "SetHfssProp": _RpcInfo(buffer=True),
        "GetLayer": _RpcInfo(cache=True),
        "SetLayer": _RpcInfo(buffer=True),
        "GetIsNegative": _RpcInfo(cache=True),
        "SetIsNegative": _RpcInfo(buffer=True),
        "IsVoid": _RpcInfo(cache=True),
        "HasVoids": _RpcInfo(cache=True),
        "Voids": _RpcInfo(read_no_cache=True),
        "StreamVoids": _RpcInfo(read_no_cache=True),
        "GetOwner": _RpcInfo(cache=True),
        "IsParameterized": _RpcInfo(cache=True),
        "GetHfssProp": _RpcInfo(cache=True),
        "RemoveHfssProp": _RpcInfo(buffer=True),
        "IsZonePrimitive": _RpcInfo(cache=True),
        "MakeZonePrimitive": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.PrimitiveInstanceCollectionService": {
        "GetGeometry": _RpcInfo(cache=True),
        "SetGeometry": _RpcInfo(buffer=True),
        "GetPositions": _RpcInfo(read_no_cache=True),
        "GetInstantiatedGeometry": _RpcInfo(read_no_cache=True),
        "Decompose": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.Q3DGeneralSettingsService": {
        "GetSolutionFrequency": _RpcInfo(cache=True),
        "SetSolutionFrequency": _RpcInfo(buffer=True),
        "GetDoDC": _RpcInfo(cache=True),
        "SetDoDC": _RpcInfo(buffer=True),
        "GetDoDCResOnly": _RpcInfo(cache=True),
        "SetDoDCResOnly": _RpcInfo(buffer=True),
        "GetDoCG": _RpcInfo(cache=True),
        "SetDoCG": _RpcInfo(buffer=True),
        "GetDoAC": _RpcInfo(cache=True),
        "SetDoAC": _RpcInfo(buffer=True),
        "GetSaveFields": _RpcInfo(cache=True),
        "SetSaveFields": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.Q3DSettingsService": {
        "GetMaxPasses": _RpcInfo(cache=True),
        "SetMaxPasses": _RpcInfo(buffer=True),
        "GetMinPasses": _RpcInfo(cache=True),
        "SetMinPasses": _RpcInfo(buffer=True),
        "GetMinConvergedPasses": _RpcInfo(cache=True),
        "SetMinConvergedPasses": _RpcInfo(buffer=True),
        "GetPercentError": _RpcInfo(cache=True),
        "SetPercentError": _RpcInfo(buffer=True),
        "GetMaxRefinePerPass": _RpcInfo(cache=True),
        "SetMaxRefinePerPass": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.Q3DDCRLSettingsService": {
        "GetSolutionOrder": _RpcInfo(cache=True),
        "SetSolutionOrder": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.Q3DCGSettingsService": {
        "GetAutoIncrSolOrder": _RpcInfo(cache=True),
        "SetAutoIncrSolOrder": _RpcInfo(buffer=True),
        "GetSolutionOrder": _RpcInfo(cache=True),
        "SetSolutionOrder": _RpcInfo(buffer=True),
        "GetSolverType": _RpcInfo(cache=True),
        "SetSolverType": _RpcInfo(buffer=True),
        "GetCompressionTol": _RpcInfo(cache=True),
        "SetCompressionTol": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.Q3DAdvancedSettingsService": {
        "GetICModeAutoResolution": _RpcInfo(cache=True),
        "SetICModeAutoResolution": _RpcInfo(buffer=True),
        "GetICModeLength": _RpcInfo(cache=True),
        "SetICModeLength": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.Q3DAdvancedMeshingSettingsService": {
        "GetLayerAlignment": _RpcInfo(cache=True),
        "SetLayerAlignment": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.RaptorXGeneralSettingsService": {
        "GetUseGoldEMSolver": _RpcInfo(cache=True),
        "SetUseGoldEMSolver": _RpcInfo(buffer=True),
        "GetMaxFrequency": _RpcInfo(cache=True),
        "SetMaxFrequency": _RpcInfo(buffer=True),
        "GetGlobalTemperature": _RpcInfo(cache=True),
        "SetGlobalTemperature": _RpcInfo(buffer=True),
        "GetSaveNetlist": _RpcInfo(cache=True),
        "SetSaveNetlist": _RpcInfo(buffer=True),
        "GetNetlistExportSpectre": _RpcInfo(cache=True),
        "SetNetlistExportSpectre": _RpcInfo(buffer=True),
        "GetSaveRFM": _RpcInfo(cache=True),
        "SetSaveRFM": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.RaptorXAdvancedSettingsService": {
        "GetUseMeshFrequency": _RpcInfo(cache=True),
        "SetUseMeshFrequency": _RpcInfo(buffer=True),
        "GetMeshFrequency": _RpcInfo(cache=True),
        "SetMeshFrequency": _RpcInfo(buffer=True),
        "GetUseEdgeMesh": _RpcInfo(cache=True),
        "SetUseEdgeMesh": _RpcInfo(buffer=True),
        "GetEdgeMesh": _RpcInfo(cache=True),
        "SetEdgeMesh": _RpcInfo(buffer=True),
        "GetUseCellsPerWavelength": _RpcInfo(cache=True),
        "SetUseCellsPerWavelength": _RpcInfo(buffer=True),
        "GetCellsPerWavelength": _RpcInfo(cache=True),
        "SetCellsPerWavelength": _RpcInfo(buffer=True),
        "GetUsePlaneProjectionFactor": _RpcInfo(cache=True),
        "SetUsePlaneProjectionFactor": _RpcInfo(buffer=True),
        "GetPlaneProjectionFactor": _RpcInfo(cache=True),
        "SetPlaneProjectionFactor": _RpcInfo(buffer=True),
        "GetUseRelaxedZAxis": _RpcInfo(cache=True),
        "SetUseRelaxedZAxis": _RpcInfo(buffer=True),
        "GetUseEliminateSlitPerHoles": _RpcInfo(cache=True),
        "SetUseEliminateSlitPerHoles": _RpcInfo(buffer=True),
        "GetEliminateSlitPerHoles": _RpcInfo(cache=True),
        "SetEliminateSlitPerHoles": _RpcInfo(buffer=True),
        "GetUseAutoRemovalSliverPoly": _RpcInfo(cache=True),
        "SetUseAutoRemovalSliverPoly": _RpcInfo(buffer=True),
        "GetAutoRemovalSliverPoly": _RpcInfo(cache=True),
        "SetAutoRemovalSliverPoly": _RpcInfo(buffer=True),
        "GetUseAccelerateViaExtraction": _RpcInfo(cache=True),
        "SetUseAccelerateViaExtraction": _RpcInfo(buffer=True),
        "GetUseEnableSubstrateNetworkExtraction": _RpcInfo(cache=True),
        "SetUseEnableSubstrateNetworkExtraction": _RpcInfo(buffer=True),
        "GetUseLDE": _RpcInfo(cache=True),
        "SetUseLDE": _RpcInfo(buffer=True),
        "GetUseExtractFloatingMetalsDummy": _RpcInfo(cache=True),
        "SetUseExtractFloatingMetalsDummy": _RpcInfo(buffer=True),
        "GetUseExtractFloatingMetalsFloating": _RpcInfo(cache=True),
        "SetUseExtractFloatingMetalsFloating": _RpcInfo(buffer=True),
        "GetUseEnableEtchTransform": _RpcInfo(cache=True),
        "SetUseEnableEtchTransform": _RpcInfo(buffer=True),
        "GetUseEnableHybridExtraction": _RpcInfo(cache=True),
        "SetUseEnableHybridExtraction": _RpcInfo(buffer=True),
        "GetUseEnableAdvancedCapEffects": _RpcInfo(cache=True),
        "SetUseEnableAdvancedCapEffects": _RpcInfo(buffer=True),
        "GetUseOverrideShrinkFac": _RpcInfo(cache=True),
        "SetUseOverrideShrinkFac": _RpcInfo(buffer=True),
        "GetOverrideShrinkFac": _RpcInfo(cache=True),
        "SetOverrideShrinkFac": _RpcInfo(buffer=True),
        "GetAdvancedOptions": _RpcInfo(cache=True),
        "SetAdvancedOptions": _RpcInfo(buffer=True),
        "GetNetSettingsOptions": _RpcInfo(cache=True),
        "SetNetSettingsOptions": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.RectangleService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetParameters": _RpcInfo(cache=True),
        "SetParameters": _RpcInfo(buffer=True),
        "Render": _RpcInfo(cache=True),
        "GetPolygonData": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.RLCComponentPropertyService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetEnabled": _RpcInfo(cache=True),
        "SetEnabled": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.RTreeService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetExtent": _RpcInfo(cache=True),
        "InsertIntObject": _RpcInfo(buffer=True),
        "DeleteIntObject": _RpcInfo(buffer=True),
        "Empty": _RpcInfo(cache=True),
        "Search": _RpcInfo(cache=True),
        "NearestNeighbor": _RpcInfo(cache=True),
        "TouchingGeometry": _RpcInfo(cache=True),
        "ConnectedGeometry": _RpcInfo(cache=True),
        "GetConnectedGeometrySets": _RpcInfo(cache=True),
        "IncrementVisit": _RpcInfo(buffer=True),
        "IsVisited": _RpcInfo(cache=True),
        "Visit": _RpcInfo(buffer=True),
        "GetVisit": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.SimulationSettingsService": {
        "GetEnabled": _RpcInfo(cache=True),
        "SetEnabled": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SettingsOptionsService": {
        "GetDoLamdaRefineFlag": _RpcInfo(cache=True),
        "SetDoLamdaRefineFlag": _RpcInfo(buffer=True),
        "GetLamdaTarget": _RpcInfo(cache=True),
        "SetLamdaTarget": _RpcInfo(buffer=True),
        "GetMeshSizefactor": _RpcInfo(cache=True),
        "SetMeshSizefactor": _RpcInfo(buffer=True),
        "GetUseDefaultLamda": _RpcInfo(cache=True),
        "SetUseDefaultLamda": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.AdvancedSettingsService": {
        "GetUnionPolygons": _RpcInfo(cache=True),
        "SetUnionPolygons": _RpcInfo(buffer=True),
        "GetRemoveFloatingGeometry": _RpcInfo(cache=True),
        "SetRemoveFloatingGeometry": _RpcInfo(buffer=True),
        "GetHealingOption": _RpcInfo(cache=True),
        "SetHealingOption": _RpcInfo(buffer=True),
        "GetSmallVoidArea": _RpcInfo(cache=True),
        "SetSmallVoidArea": _RpcInfo(buffer=True),
        "GetUseDefeature": _RpcInfo(cache=True),
        "SetUseDefeature": _RpcInfo(buffer=True),
        "GetUseDefeatureAbsoluteLength": _RpcInfo(cache=True),
        "SetUseDefeatureAbsoluteLength": _RpcInfo(buffer=True),
        "GetDefeatureAbsoluteLength": _RpcInfo(cache=True),
        "SetDefeatureAbsoluteLength": _RpcInfo(buffer=True),
        "GetDefeatureRatio": _RpcInfo(cache=True),
        "SetDefeatureRatio": _RpcInfo(buffer=True),
        "GetViaModelType": _RpcInfo(cache=True),
        "SetViaModelType": _RpcInfo(buffer=True),
        "GetNumViaSides": _RpcInfo(cache=True),
        "SetNumViaSides": _RpcInfo(buffer=True),
        "GetViaDensity": _RpcInfo(cache=True),
        "SetViaDensity": _RpcInfo(buffer=True),
        "GetViaMaterial": _RpcInfo(cache=True),
        "SetViaMaterial": _RpcInfo(buffer=True),
        "GetMeshForViaPlating": _RpcInfo(cache=True),
        "SetMeshForViaPlating": _RpcInfo(buffer=True),
        "GetModelType": _RpcInfo(cache=True),
        "SetModelType": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.AdvancedMeshingSettingsService": {
        "GetArcStepSize": _RpcInfo(cache=True),
        "SetArcStepSize": _RpcInfo(buffer=True),
        "GetCircleStartAzimuth": _RpcInfo(cache=True),
        "SetCircleStartAzimuth": _RpcInfo(buffer=True),
        "GetMaxNumArcPoints": _RpcInfo(cache=True),
        "SetMaxNumArcPoints": _RpcInfo(buffer=True),
        "GetUseArcChordErrorApprox": _RpcInfo(cache=True),
        "SetUseArcChordErrorApprox": _RpcInfo(buffer=True),
        "GetArcChordErrorApprox": _RpcInfo(cache=True),
        "SetArcChordErrorApprox": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SolverSettingsService": {
        "GetThinSignalLayerThreshold": _RpcInfo(cache=True),
        "SetThinSignalLayerThreshold": _RpcInfo(buffer=True),
        "GetThinDielectricLayerThreshold": _RpcInfo(cache=True),
        "SetThinDielectricLayerThreshold": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SimulationSetupService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "GetPosition": _RpcInfo(cache=True),
        "SetPosition": _RpcInfo(buffer=True),
        "GetSweepData": _RpcInfo(cache=True),
        "SetSweepData": _RpcInfo(buffer=True),
        "GetType": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.SIWaveDCIRSimulationSettingsService": {
        "GetIcepakTempFile": _RpcInfo(cache=True),
        "SetIcepakTempFile": _RpcInfo(buffer=True),
        "GetSourceTermsToGround": _RpcInfo(cache=True),
        "SetSourceTermsToGround": _RpcInfo(buffer=True),
        "GetExportDCThermalData": _RpcInfo(cache=True),
        "SetExportDCThermalData": _RpcInfo(buffer=True),
        "GetImportThermalData": _RpcInfo(cache=True),
        "SetImportThermalData": _RpcInfo(buffer=True),
        "GetFullDCReportPath": _RpcInfo(cache=True),
        "SetFullDCReportPath": _RpcInfo(buffer=True),
        "GetViaReportPath": _RpcInfo(cache=True),
        "SetViaReportPath": _RpcInfo(buffer=True),
        "GetPerPinResPath": _RpcInfo(cache=True),
        "SetPerPinResPath": _RpcInfo(buffer=True),
        "GetDCReportConfigFile": _RpcInfo(cache=True),
        "SetDCReportConfigFile": _RpcInfo(buffer=True),
        "GetDCReportShowActiveDevices": _RpcInfo(cache=True),
        "SetDCReportShowActiveDevices": _RpcInfo(buffer=True),
        "GetPerPinUsePinFormat": _RpcInfo(cache=True),
        "SetPerPinUsePinFormat": _RpcInfo(buffer=True),
        "GetUseLoopResForPerPin": _RpcInfo(cache=True),
        "SetUseLoopResForPerPin": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SIWaveGeneralSettingsService": {
        "GetUseSISettings": _RpcInfo(cache=True),
        "SetUseSISettings": _RpcInfo(buffer=True),
        "GetUseCustomSettings": _RpcInfo(cache=True),
        "SetUseCustomSettings": _RpcInfo(buffer=True),
        "GetSISliderPos": _RpcInfo(cache=True),
        "SetSISliderPos": _RpcInfo(buffer=True),
        "GetPISliderPos": _RpcInfo(cache=True),
        "SetPISliderPos": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SIWaveAdvancedSettingsService": {
        "GetIncludeCoPlaneCoupling": _RpcInfo(cache=True),
        "SetIncludeCoPlaneCoupling": _RpcInfo(buffer=True),
        "GetIncludeInterPlaneCoupling": _RpcInfo(cache=True),
        "SetIncludeInterPlaneCoupling": _RpcInfo(buffer=True),
        "GetIncludeSplitPlaneCoupling": _RpcInfo(cache=True),
        "SetIncludeSplitPlaneCoupling": _RpcInfo(buffer=True),
        "GetIncludeFringePlaneCoupling": _RpcInfo(cache=True),
        "SetIncludeFringePlaneCoupling": _RpcInfo(buffer=True),
        "GetIncludeTracePlaneCoupling": _RpcInfo(cache=True),
        "SetIncludeTracePlaneCoupling": _RpcInfo(buffer=True),
        "GetCrossTalkThreshold": _RpcInfo(cache=True),
        "SetCrossTalkThreshold": _RpcInfo(buffer=True),
        "GetMaxCoupledLines": _RpcInfo(cache=True),
        "SetMaxCoupledLines": _RpcInfo(buffer=True),
        "GetMinVoidArea": _RpcInfo(cache=True),
        "SetMinVoidArea": _RpcInfo(buffer=True),
        "GetMinPadAreaToMesh": _RpcInfo(cache=True),
        "SetMinPadAreaToMesh": _RpcInfo(buffer=True),
        "GetMinPlaneAreaToMesh": _RpcInfo(cache=True),
        "SetMinPlaneAreaToMesh": _RpcInfo(buffer=True),
        "GetSnapLengthThreshold": _RpcInfo(cache=True),
        "SetSnapLengthThreshold": _RpcInfo(buffer=True),
        "GetMeshAutomatic": _RpcInfo(cache=True),
        "SetMeshAutomatic": _RpcInfo(buffer=True),
        "GetMeshFrequency": _RpcInfo(cache=True),
        "SetMeshFrequency": _RpcInfo(buffer=True),
        "GetAcDcMergeMode": _RpcInfo(cache=True),
        "SetAcDcMergeMode": _RpcInfo(buffer=True),
        "Get3DReturnCurrentDistribution": _RpcInfo(cache=True),
        "Set3DReturnCurrentDistribution": _RpcInfo(buffer=True),
        "GetIncludeVISources": _RpcInfo(cache=True),
        "SetIncludeVISources": _RpcInfo(buffer=True),
        "GetIncludeInfGnd": _RpcInfo(cache=True),
        "SetIncludeInfGnd": _RpcInfo(buffer=True),
        "GetInfGndLocation": _RpcInfo(cache=True),
        "SetInfGndLocation": _RpcInfo(buffer=True),
        "GetPerformERC": _RpcInfo(cache=True),
        "SetPerformERC": _RpcInfo(buffer=True),
        "GetIgnoreNonFunctionalPads": _RpcInfo(cache=True),
        "SetIgnoreNonFunctionalPads": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SIWaveDCSettingsService": {
        "GetUseDCCustomSettings": _RpcInfo(cache=True),
        "SetUseDCCustomSettings": _RpcInfo(buffer=True),
        "GetComputeInductance": _RpcInfo(cache=True),
        "SetComputeInductance": _RpcInfo(buffer=True),
        "GetPlotJV": _RpcInfo(cache=True),
        "SetPlotJV": _RpcInfo(buffer=True),
        "GetContactRadius": _RpcInfo(cache=True),
        "SetContactRadius": _RpcInfo(buffer=True),
        "GetDCSliderPos": _RpcInfo(cache=True),
        "SetDCSliderPos": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SIWaveDCAdvancedSettingsService": {
        "GetDCMinPlaneAreaToMesh": _RpcInfo(cache=True),
        "SetDCMinPlaneAreaToMesh": _RpcInfo(buffer=True),
        "GetDCMinVoidAreaToMesh": _RpcInfo(cache=True),
        "SetDCMinVoidAreaToMesh": _RpcInfo(buffer=True),
        "GetMaxInitMeshEdgeLength": _RpcInfo(cache=True),
        "SetMaxInitMeshEdgeLength": _RpcInfo(buffer=True),
        "GetPerformAdaptiveRefinement": _RpcInfo(cache=True),
        "SetPerformAdaptiveRefinement": _RpcInfo(buffer=True),
        "GetMaxNumPasses": _RpcInfo(cache=True),
        "SetMaxNumPasses": _RpcInfo(buffer=True),
        "GetMinNumPasses": _RpcInfo(cache=True),
        "SetMinNumPasses": _RpcInfo(buffer=True),
        "GetPercentLocalRefinement": _RpcInfo(cache=True),
        "SetPercentLocalRefinement": _RpcInfo(buffer=True),
        "GetEnergyError": _RpcInfo(cache=True),
        "SetEnergyError": _RpcInfo(buffer=True),
        "GetMeshBws": _RpcInfo(cache=True),
        "SetMeshBws": _RpcInfo(buffer=True),
        "GetRefineBws": _RpcInfo(cache=True),
        "SetRefineBws": _RpcInfo(buffer=True),
        "GetMeshVias": _RpcInfo(cache=True),
        "SetMeshVias": _RpcInfo(buffer=True),
        "GetRefineVias": _RpcInfo(cache=True),
        "SetRefineVias": _RpcInfo(buffer=True),
        "GetNumBwSides": _RpcInfo(cache=True),
        "SetNumBwSides": _RpcInfo(buffer=True),
        "GetNumViaSides": _RpcInfo(cache=True),
        "SetNumViaSides": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SIWaveSParameterSettingsService": {
        "GetUseStateSpace": _RpcInfo(cache=True),
        "SetUseStateSpace": _RpcInfo(buffer=True),
        "GetInterpolation": _RpcInfo(cache=True),
        "SetInterpolation": _RpcInfo(buffer=True),
        "GetExtrapolation": _RpcInfo(cache=True),
        "SetExtrapolation": _RpcInfo(buffer=True),
        "GetDCBehavior": _RpcInfo(cache=True),
        "SetDCBehavior": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SolderBallPropertyService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetShape": _RpcInfo(cache=True),
        "SetShape": _RpcInfo(buffer=True),
        "GetPlacement": _RpcInfo(cache=True),
        "SetPlacement": _RpcInfo(buffer=True),
        "GetDiameter": _RpcInfo(cache=True),
        "SetDiameter": _RpcInfo(buffer=True),
        "GetHeight": _RpcInfo(cache=True),
        "SetHeight": _RpcInfo(buffer=True),
        "GetMaterialName": _RpcInfo(cache=True),
        "SetMaterialName": _RpcInfo(buffer=True),
        "UsesSolderball": _RpcInfo(cache=True),
        "Clone": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
    },
    "ansys.api.edb.v1.SpiceModelService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetProperties": _RpcInfo(cache=True),
        "SetModelPath": _RpcInfo(buffer=True),
        "SetModelName": _RpcInfo(buffer=True),
        "SetSubCkt": _RpcInfo(buffer=True),
        "AddTerminalPinPair": _RpcInfo(buffer=True),
        "RemoveTerminalPinPair": _RpcInfo(buffer=True),
        "GetTerminalPinPairs": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.StackupLayerService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetNegative": _RpcInfo(cache=True),
        "SetNegative": _RpcInfo(buffer=True),
        "GetThickness": _RpcInfo(cache=True),
        "SetThickness": _RpcInfo(buffer=True),
        "GetLowerElevation": _RpcInfo(cache=True),
        "SetLowerElevation": _RpcInfo(buffer=True),
        "GetUpperElevation": _RpcInfo(cache=True),
        "GetMaterial": _RpcInfo(cache=True),
        "SetMaterial": _RpcInfo(buffer=True),
        "GetFillMaterial": _RpcInfo(cache=True),
        "SetFillMaterial": _RpcInfo(buffer=True),
        "SetRoughnessEnabled": _RpcInfo(buffer=True),
        "IsRoughnessEnabled": _RpcInfo(cache=True),
        "GetRoughnessModel": _RpcInfo(cache=True),
        "SetRoughnessModel": _RpcInfo(buffer=True),
        "IsEtchFactorEnabled": _RpcInfo(cache=True),
        "SetEtchFactorEnabled": _RpcInfo(buffer=True),
        "SetEtchFactor": _RpcInfo(buffer=True),
        "GetEtchFactor": _RpcInfo(cache=True),
        "SetEtchNetClass": _RpcInfo(buffer=True),
        "GetEtchNetClass": _RpcInfo(cache=True),
        "GetUseSolverProperties": _RpcInfo(cache=True),
        "SetUseSolverProperties": _RpcInfo(buffer=True),
        "GetHFSSSolverProperties": _RpcInfo(cache=True),
        "SetHFSSSolverProperties": _RpcInfo(buffer=True),
        "GetReferencingViaLayerIds": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.Structure3DService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetMaterial": _RpcInfo(cache=True),
        "SetMaterial": _RpcInfo(buffer=True),
        "GetThickness": _RpcInfo(cache=True),
        "SetThickness": _RpcInfo(buffer=True),
        "GetMeshClosureProp": _RpcInfo(cache=True),
        "SetMeshClosureProp": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.SParameterModelService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetProperties": _RpcInfo(cache=True),
        "SetComponentModelName": _RpcInfo(buffer=True),
        "SetReferenceNet": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.TerminalService": {
        "FindByName": _RpcInfo(buffer=True, returns_future=True),
        "GetParams": _RpcInfo(cache=True),
        "SetParams": _RpcInfo(buffer=True),
        "GetProductSolvers": _RpcInfo(cache=True),
        "SetProductSolverOptions": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.TerminalInstanceService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetOwningCellInstance": _RpcInfo(cache=True),
        "GetDefinitionTerminal": _RpcInfo(cache=True),
        "GetDefinitionTerminalName": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.TerminalInstanceTerminalService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetTerminalInstance": _RpcInfo(cache=True),
        "SetTerminalInstance": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.TextService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetTextData": _RpcInfo(cache=True),
        "SetTextData": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.TransformService": {
        "Rotate": _RpcInfo(cache=True),
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetScale": _RpcInfo(cache=True),
        "SetScale": _RpcInfo(buffer=True),
        "GetMirror": _RpcInfo(cache=True),
        "SetMirror": _RpcInfo(buffer=True),
        "GetRotation": _RpcInfo(cache=True),
        "SetRotation": _RpcInfo(buffer=True),
        "GetOffsetX": _RpcInfo(cache=True),
        "SetOffsetX": _RpcInfo(buffer=True),
        "GetOffsetY": _RpcInfo(cache=True),
        "SetOffsetY": _RpcInfo(buffer=True),
        "TransformPlus": _RpcInfo(buffer=True, returns_future=True),
        "IsIdentity": _RpcInfo(cache=True),
        "TransformPoint": _RpcInfo(cache=True),
        "TransformPolygon": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.Transform3DService": {
        "CreateIdentity": _RpcInfo(
            buffer=True, returns_future=True, write_no_cache_invalidation=True
        ),
        "CreateCopy": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "CreateOffset": _RpcInfo(
            buffer=True, returns_future=True, write_no_cache_invalidation=True
        ),
        "CreateCenterScale": _RpcInfo(
            buffer=True, returns_future=True, write_no_cache_invalidation=True
        ),
        "CreateRotationFromAngle": _RpcInfo(
            buffer=True, returns_future=True, write_no_cache_invalidation=True
        ),
        "CreateRotationFromAxis": _RpcInfo(
            buffer=True, returns_future=True, write_no_cache_invalidation=True
        ),
        "CreateRotationFromAxisAndAngle": _RpcInfo(
            buffer=True, returns_future=True, write_no_cache_invalidation=True
        ),
        "CreateRotationFromToAxis": _RpcInfo(
            buffer=True, returns_future=True, write_no_cache_invalidation=True
        ),
        "CreateTransform2D": _RpcInfo(
            buffer=True, returns_future=True, write_no_cache_invalidation=True
        ),
        "OperatorPlus": _RpcInfo(
            buffer=True, returns_future=True, write_no_cache_invalidation=True
        ),
        "TransformPoint": _RpcInfo(cache=True),
        "GetZYXRotation": _RpcInfo(cache=True),
        "GetAxis": _RpcInfo(cache=True),
        "Transpose": _RpcInfo(buffer=True),
        "Invert": _RpcInfo(buffer=True),
        "IsIdentity": _RpcInfo(cache=True),
        "IsEqual": _RpcInfo(cache=True),
        "GetScaling": _RpcInfo(cache=True),
        "GetShift": _RpcInfo(cache=True),
        "SetMatrix": _RpcInfo(buffer=True),
        "GetMatrix": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.ValueService": {
        "GetDouble": _RpcInfo(cache=True),
        "GetComplex": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.VariableServerService": {
        "AddVariable": _RpcInfo(buffer=True),
        "AddMenuVariable": _RpcInfo(buffer=True),
        "DeleteVariable": _RpcInfo(buffer=True),
        "SetVariableValue": _RpcInfo(buffer=True),
        "GetVariableValue": _RpcInfo(cache=True),
        "IsParameter": _RpcInfo(cache=True),
        "GetAllVariableNames": _RpcInfo(cache=True),
        "GetVariableDesc": _RpcInfo(cache=True),
        "SetVariableDesc": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.ViaGroupService": {
        "CreateWithOutline": _RpcInfo(buffer=True, returns_future=True),
        "FindByName": _RpcInfo(cache=True),
        "GetOutline": _RpcInfo(cache=True),
        "GetConductorPercentage": _RpcInfo(cache=True),
        "IsPersistent": _RpcInfo(cache=True),
    },
    "ansys.api.edb.v1.ViaLayerService": {
        "Create": _RpcInfo(buffer=True, returns_future=True, write_no_cache_invalidation=True),
        "GetRefLayerName": _RpcInfo(cache=True),
        "SetRefLayer": _RpcInfo(buffer=True),
    },
    "ansys.api.edb.v1.VoltageRegulatorService": {
        "Create": _RpcInfo(buffer=True, returns_future=True),
        "GetName": _RpcInfo(cache=True),
        "SetName": _RpcInfo(buffer=True),
        "IsActive": _RpcInfo(cache=True),
        "SetIsActive": _RpcInfo(buffer=True),
        "GetVoltage": _RpcInfo(cache=True),
        "SetVoltage": _RpcInfo(buffer=True),
        "GetLoadRegulationCurrent": _RpcInfo(cache=True),
        "SetLoadRegulationCurrent": _RpcInfo(buffer=True),
        "GetLoadRegulationPercent": _RpcInfo(cache=True),
        "SetLoadRegulationPercent": _RpcInfo(buffer=True),
        "GetPosRemoteSensePin": _RpcInfo(cache=True),
        "SetPosRemoteSensePin": _RpcInfo(buffer=True),
        "GetNegRemoteSensePin": _RpcInfo(cache=True),
        "SetNegRemoteSensePin": _RpcInfo(buffer=True),
        "GetNPowerModules": _RpcInfo(cache=True),
        "GetNActivePowerModules": _RpcInfo(cache=True),
        "GetPowerModule": _RpcInfo(cache=True),
        "GetAllPowerModules": _RpcInfo(cache=True),
        "AddPowerModule": _RpcInfo(buffer=True),
        "RemovePowerModule": _RpcInfo(buffer=True),
        "AddPowerModules": _RpcInfo(buffer=True),
        "RemovePowerModules": _RpcInfo(buffer=True),
        "RemoveAllPowerModules": _RpcInfo(buffer=True),
    },
}
